Title: 

URL Source: https://globalwordnet.github.io/gwadoc/

Published Time: Sat, 24 Dec 2022 13:43:21 GMT

Markdown Content:
Overview
--------

#### What is wordnet?

Unlike a standard dictionary, which takes the word as its elementary building block, a wordnet is an online lexical reference system which is organized by concepts.

The basic building block of a wordnet is Synonym set (**Synset**), a group of words that can all refer to the same concept, such as [_shut_](https://www.luismc.com/omw/ili/concepts/28418) and [_close_](https://www.luismc.com/omw/ili/concepts/28418) or [_car_](https://www.luismc.com/omw/ili/concepts/51496) and [_automobile_](https://www.luismc.com/omw/ili/concepts/51496). Words and synsets are linked by means of conceptual-semantic relations in wordnet.

The core conceptual-semantic relations among synsets are called **Constitutive** relations, such as:

*   Super-subordinate relation (hypernym and hyponym)
*   Part-whole relation (meronym and holonym)
*   Semantic contract and similar relation (antonym and synonym)

Synsets are connected into a net framework to form the structure of wordnet, you can refer to this document for the details of Constitutive and other types of relations.

Currently, [Princeton Wordnet](https://www.luismc.com/omw/omw/src/pwn/3.0) of English is the most complete and accurate wordnet, and is commonly used as a reference for other wordnets. You can also visit [Princeton Wordnet project homepage](https://wordnet.princeton.edu/) to learn more of this wordnet.

[Open Multilingual Wordnet](https://www.luismc.com/omw/omw) (OMW) is a collection of wordnets in a variety of languages, all linked through the [Collaborative Interlingual Index](https://www.luismc.com/omw/ili) (CILI), the goal is to make it easy to use wordnets across multiple languages, you can browse and search for cross-lingual matches in OMW.

#### What is Global Wordnet Association?

The [Global WordNet Association](http://globalwordnet.org/) (GWA) is a free, public and non-commercial organization that provides a platform for discussing, sharing and connecting semantic lexicons (wordnets) for all languages in the world. Our goal is to make compatible, linked, open lexical resources useful for both humans and computers.

Table of Contents
-----------------

*   [Constitutive](https://globalwordnet.github.io/gwadoc/#constitutive) (constitutive) 
    *   [Hyponym](https://globalwordnet.github.io/gwadoc/#hyponym) (hyponym)⇔[Hypernym](https://globalwordnet.github.io/gwadoc/#hypernym) (hypernym) 
        *   [Feminine](https://globalwordnet.github.io/gwadoc/#feminine) (feminine)⇔[Has Feminine](https://globalwordnet.github.io/gwadoc/#has_feminine) (has_feminine) 
        *   [Masculine](https://globalwordnet.github.io/gwadoc/#masculine) (masculine)⇔[Has Masculine](https://globalwordnet.github.io/gwadoc/#has_masculine) (has_masculine) 
        *   [Young](https://globalwordnet.github.io/gwadoc/#young) (young)⇔[Has Young](https://globalwordnet.github.io/gwadoc/#has_young) (has_young) 

    *   [Instance Hyponym](https://globalwordnet.github.io/gwadoc/#instance_hyponym) (instance_hyponym)⇔[Instance Hypernym](https://globalwordnet.github.io/gwadoc/#instance_hypernym) (instance_hypernym) 
    *   [Antonym](https://globalwordnet.github.io/gwadoc/#antonym) (antonym) 
        *   [Gradable Antonym](https://globalwordnet.github.io/gwadoc/#anto_gradable) (anto_gradable) 
        *   [Simple Antonym](https://globalwordnet.github.io/gwadoc/#anto_simple) (anto_simple) 
        *   [Converse Antonym](https://globalwordnet.github.io/gwadoc/#anto_converse) (anto_converse) 

    *   [Equal Synonym](https://globalwordnet.github.io/gwadoc/#eq_synonym) (eq_synonym) 
        *   [Inter-register Synonym](https://globalwordnet.github.io/gwadoc/#ir_synonym) (ir_synonym) 

    *   [Similar](https://globalwordnet.github.io/gwadoc/#similar) (similar) 
    *   [Meronym](https://globalwordnet.github.io/gwadoc/#meronym) (meronym)⇔[Holonym](https://globalwordnet.github.io/gwadoc/#holonym) (holonym) 
        *   [Location Meronym](https://globalwordnet.github.io/gwadoc/#mero_location) (mero_location)⇔[Location Holonym](https://globalwordnet.github.io/gwadoc/#holo_location) (holo_location) 
        *   [Member Meronym](https://globalwordnet.github.io/gwadoc/#mero_member) (mero_member)⇔[Member Holonym](https://globalwordnet.github.io/gwadoc/#holo_member) (holo_member) 
        *   [Part Meronym](https://globalwordnet.github.io/gwadoc/#mero_part) (mero_part)⇔[Part Holonym](https://globalwordnet.github.io/gwadoc/#holo_part) (holo_part) 
        *   [Portion Meronym](https://globalwordnet.github.io/gwadoc/#mero_portion) (mero_portion)⇔[Portion Holonym](https://globalwordnet.github.io/gwadoc/#holo_portion) (holo_portion) 
        *   [Substance Meronym](https://globalwordnet.github.io/gwadoc/#mero_substance) (mero_substance)⇔[Substance Holonym](https://globalwordnet.github.io/gwadoc/#holo_substance) (holo_substance) 

*   [Other](https://globalwordnet.github.io/gwadoc/#other) (other) 
    *   [See also](https://globalwordnet.github.io/gwadoc/#also) (also) 
    *   [State Of](https://globalwordnet.github.io/gwadoc/#state_of) (state_of)⇔[Be In State](https://globalwordnet.github.io/gwadoc/#be_in_state) (be_in_state) 
    *   [Causes](https://globalwordnet.github.io/gwadoc/#causes) (causes)⇔[Is Caused By](https://globalwordnet.github.io/gwadoc/#is_caused_by) (is_caused_by) 
    *   [Subevent](https://globalwordnet.github.io/gwadoc/#subevent) (subevent)⇔[Is Subevent Of](https://globalwordnet.github.io/gwadoc/#is_subevent_of) (is_subevent_of) 
    *   [Manner Of](https://globalwordnet.github.io/gwadoc/#manner_of) (manner_of)⇔[In Manner](https://globalwordnet.github.io/gwadoc/#in_manner) (in_manner) 
    *   [Attribute](https://globalwordnet.github.io/gwadoc/#attribute) (attribute) 
    *   [Restricts](https://globalwordnet.github.io/gwadoc/#restricts) (restricts)⇔[Restricted By](https://globalwordnet.github.io/gwadoc/#restricted_by) (restricted_by) 
    *   [Classifies](https://globalwordnet.github.io/gwadoc/#classifies) (classifies)⇔[Classified By](https://globalwordnet.github.io/gwadoc/#classified_by) (classified_by) 
    *   [Entails](https://globalwordnet.github.io/gwadoc/#entails) (entails)⇔[Is Entailed By](https://globalwordnet.github.io/gwadoc/#is_entailed_by) (is_entailed_by) 

*   [Domain](https://globalwordnet.github.io/gwadoc/#domain) (domain)⇔[In Domain](https://globalwordnet.github.io/gwadoc/#has_domain) (has_domain) 
    *   [Domain Topic](https://globalwordnet.github.io/gwadoc/#domain_topic) (domain_topic)⇔[Has Domain Topic](https://globalwordnet.github.io/gwadoc/#has_domain_topic) (has_domain_topic) 
    *   [Domain Region](https://globalwordnet.github.io/gwadoc/#domain_region) (domain_region)⇔[Has Domain Region](https://globalwordnet.github.io/gwadoc/#has_domain_region) (has_domain_region) 
    *   [Exemplifies](https://globalwordnet.github.io/gwadoc/#exemplifies) (exemplifies)⇔[Is Exemplified By](https://globalwordnet.github.io/gwadoc/#is_exemplified_by) (is_exemplified_by) 

*   [Role](https://globalwordnet.github.io/gwadoc/#role) (role)⇔[Involved](https://globalwordnet.github.io/gwadoc/#involved) (involved) 
    *   [Agent](https://globalwordnet.github.io/gwadoc/#agent) (agent)⇔[Involved Agent](https://globalwordnet.github.io/gwadoc/#involved_agent) (involved_agent) 
    *   [Patient](https://globalwordnet.github.io/gwadoc/#patient) (patient)⇔[Involved Patient](https://globalwordnet.github.io/gwadoc/#involved_patient) (involved_patient) 
    *   [Result](https://globalwordnet.github.io/gwadoc/#result) (result)⇔[Involved Result](https://globalwordnet.github.io/gwadoc/#involved_result) (involved_result) 
    *   [Instrument](https://globalwordnet.github.io/gwadoc/#instrument) (instrument)⇔[Involved Instrument](https://globalwordnet.github.io/gwadoc/#involved_instrument) (involved_instrument) 
    *   [Location](https://globalwordnet.github.io/gwadoc/#location) (location)⇔[Involved Location](https://globalwordnet.github.io/gwadoc/#involved_location) (involved_location) 
    *   [Direction](https://globalwordnet.github.io/gwadoc/#direction) (direction)⇔[Involved Direction](https://globalwordnet.github.io/gwadoc/#involved_direction) (involved_direction) 
    *   [Target Direction](https://globalwordnet.github.io/gwadoc/#target_direction) (target_direction)⇔[Involved Target Direction](https://globalwordnet.github.io/gwadoc/#involved_target_direction) (involved_target_direction) 
    *   [Source Direction](https://globalwordnet.github.io/gwadoc/#source_direction) (source_direction)⇔[Involved Source Direction](https://globalwordnet.github.io/gwadoc/#involved_source_direction) (involved_source_direction) 
    *   [Co Role](https://globalwordnet.github.io/gwadoc/#co_role) (co_role) 
        *   [Co Agent Patient](https://globalwordnet.github.io/gwadoc/#co_agent_patient) (co_agent_patient)⇔[Co Patient Agent](https://globalwordnet.github.io/gwadoc/#co_patient_agent) (co_patient_agent) 
        *   [Co Agent Instrument](https://globalwordnet.github.io/gwadoc/#co_agent_instrument) (co_agent_instrument)⇔[Co Instrument Agent](https://globalwordnet.github.io/gwadoc/#co_instrument_agent) (co_instrument_agent) 
        *   [Co Agent Result](https://globalwordnet.github.io/gwadoc/#co_agent_result) (co_agent_result)⇔[Co Result Agent](https://globalwordnet.github.io/gwadoc/#co_result_agent) (co_result_agent) 
        *   [Co Patient Instrument](https://globalwordnet.github.io/gwadoc/#co_patient_instrument) (co_patient_instrument)⇔[Co Instrument Patient](https://globalwordnet.github.io/gwadoc/#co_instrument_patient) (co_instrument_patient) 
        *   [Co Result Instrument](https://globalwordnet.github.io/gwadoc/#co_result_instrument) (co_result_instrument)⇔[Co Instrument Result](https://globalwordnet.github.io/gwadoc/#co_instrument_result) (co_instrument_result) 

*   [Participle](https://globalwordnet.github.io/gwadoc/#participle) (participle) 
*   [Pertainym](https://globalwordnet.github.io/gwadoc/#pertainym) (pertainym) 
*   [Derivation](https://globalwordnet.github.io/gwadoc/#derivation) (derivation) 
    *   [Simple Aspect (imp to per)](https://globalwordnet.github.io/gwadoc/#simple_aspect_ip) (simple_aspect_ip)⇔[Simple Aspect (per to imp)](https://globalwordnet.github.io/gwadoc/#simple_aspect_pi) (simple_aspect_pi) 
    *   [Secondary Aspect (ip)](https://globalwordnet.github.io/gwadoc/#secondary_aspect_ip) (secondary_aspect_ip)⇔[Secondary Aspect (pi)](https://globalwordnet.github.io/gwadoc/#secondary_aspect_pi) (secondary_aspect_pi) 
    *   [Diminutive](https://globalwordnet.github.io/gwadoc/#diminutive) (diminutive)⇔[Has Diminutive](https://globalwordnet.github.io/gwadoc/#has_diminutive) (has_diminutive) 
    *   [Augmentative](https://globalwordnet.github.io/gwadoc/#augmentative) (augmentative)⇔[Has Augmentative](https://globalwordnet.github.io/gwadoc/#has_augmentative) (has_augmentative) 

Relations
---------

### [Constitutive](https://globalwordnet.github.io/gwadoc/#constitutive) (constitutive)[back to top](https://globalwordnet.github.io/gwadoc/#)

"Core semantic relations that define synsets"

| applicability | (not directly applicable) |
| --- |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

#### Definition

Core semantic relations that define synsets.

We follow the discussion in [[Maziarz:Piasecki:Szpakowicz:2013]](https://globalwordnet.github.io/gwadoc/#maziarz-piasecki-szpakowicz-2013)

[[Maziarz:Piasecki:Szpakowicz:2013]](https://globalwordnet.github.io/gwadoc/#citation-reference-1)The chicken-and-egg problem in wordnet design: synonymy, synsets and constitutive relations. Language Resources and Evaluation, 47(3), pp 769–79

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

* * *

### [Hyponym](https://globalwordnet.github.io/gwadoc/#hyponym) (hyponym)[back to top](https://globalwordnet.github.io/gwadoc/#)

"a concept that is more specific than a given concept"

| symbol | ⊂ |
| --- |
| applicability | * synset–synset |
| reverse | [hypernym](https://globalwordnet.github.io/gwadoc/#hypernym) |
| example | [dog](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/46360) is a hyponym of [animal](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/35563) |

#### Definition

A hyponym of something is its subtype: if A is a hyponym of B, then all A are B.

#### Examples

*   [beef](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48244) is a hyponym of [meat](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/77100)
*   [pear](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/77892) is a hyponym of [edible fruit](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/77500)
*   [dictionary](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/70226) is a hyponym of [wordbook](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/70225)

#### Tests

Test:
*   Hyponymy-relation between nouns (EWN test 9)

yes a _A/an A is a/an B with certain properties_
.._It is a A and therefore also a B_
.._If it is a A then it must be a B_
no b the converse of any of the (a) sentences.
Conditions:
*   both A and B are singular nouns or plural nouns.

Test:
*   Hyperonymy/hyponymy between verb synsets (EWN test 11)

yes a _to A is to B + AdvP/AdjP/NP/PP_
no b _to B is to A + AdvP/AdjP/NP/PP_
Conditions:
*   A is a verb in the infinitive form
*   B is a verb in the infinitive form
*   there is at least one specifying AdvP, NP or PP that applies to the B-phrase.

#### Comments

This is the fundamental relation, generally used for nouns and verbs. In plWordNet it is also extended to adjectives and adverbs.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="hyponym"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | hyponym |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | ~ |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_hyponym |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | hiponimia |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | hypo |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i69570](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69570)⟫ |

* * *

### [Hypernym](https://globalwordnet.github.io/gwadoc/#hypernym) (hypernym)[back to top](https://globalwordnet.github.io/gwadoc/#)

"a concept that is more general than a given concept"

| symbol | ⊃ |
| --- |
| applicability | * synset–synset |
| reverse | [hyponym](https://globalwordnet.github.io/gwadoc/#hyponym) |
| example | _animal_ is a hypernym of _dog_ |

#### Definition

A hypernym of something is its supertype: if A is a hypernym of B, then all B are A.

#### Examples

*   _meat_ is a hypernym of _beef_
*   _edible fruit_ is a hypernym of _pear_
*   _wordbook_ is a hypernym of _dictionary_

#### Tests

Hyperonymy/hyponymy between verb synsets ([[EWN]](https://globalwordnet.github.io/gwadoc/#ewn) test 11, p23)

yes a _to A is to B + AdvP/AdjP/NP/PP_
no b _to B is to A + AdvP/AdjP/NP/PP_
Conditions:
*   A is a verb in the infinitive form
*   B is a verb in the infinitive form
*   there is at least one specifying modifier (AdvP, NP or PP) that applies to the B-phrase

[[EWN]](https://globalwordnet.github.io/gwadoc/#citation-reference-1)Piek Vossen (ed.) (1999) [Euro Wordnet General Documentation](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf) University of Amsterdam

#### Comments

This is the fundamental relation, generally used for nouns and verbs. In the original Princeton WordNet the name 'troponym' was used for this relation when relating to verbs. In plWordNet it is also extended to adjectives and adverbs.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="hypernym"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | @ |
| --- |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_hyperonym |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | hiperonimia |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | hype |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i69569](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69569)⟫ |

* * *

### [Instance Hyponym](https://globalwordnet.github.io/gwadoc/#instance_hyponym) (instance_hyponym)[back to top](https://globalwordnet.github.io/gwadoc/#)

"an occurrence of something"

| applicability | * synset–synset |
| --- |
| reverse | [instance_hypernym](https://globalwordnet.github.io/gwadoc/#instance_hypernym) |
| example | [city](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81847) has instance hyponym [manchester](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83395) |

#### Definition

A relation between two concepts where concept A (instance_hyponym) is a type of concept B (instance_hypernym), and where A is an individual entity. A will be a terminal node in the hierarchy. Instances are expressed by proper nouns.

An instance hyponym can also be referred to as a type

#### Examples

*   [city](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81847) has instance_hyponym [manchester](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83395)

#### Tests

Yes A is one of the Bs
No B is one of the As

Condition: A is a proper noun (or named entity), B is a common noun.

#### Comments

Hyponymy is a relation between classes of entities. Individual entities can also be said to belong to some class. Although we do not find many instances in a lexical database, the relation is useful for users that want to add particular instances and do not want to consult a separate database. To distinguish it from class hyponymy the relation is dubbed has_instance.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="instance_hyponym"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | Instance Hyponym |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | ~i |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | instance_hyponym |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | typ |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | hasi |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i75102](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/75102)⟫ |

* * *

### [Instance Hypernym](https://globalwordnet.github.io/gwadoc/#instance_hypernym) (instance_hypernym)[back to top](https://globalwordnet.github.io/gwadoc/#)

"the type of an instance"

| applicability | * synset–synset |
| --- |
| reverse | [instance_hyponym](https://globalwordnet.github.io/gwadoc/#instance_hyponym) |
| example | [manchester](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83395) has instance hypernym [city](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81847) |

#### Definition

A relation between two concepts where concept A (instance_hyponym) is a type of concept B (instance_hypernym), and where A is an individual entity. A will be a terminal node in the hierarchy. Instances are expressed by proper nouns.

An instance hypernym can also be referred to as a type

#### Examples

*   [manchester](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83395) has instance_hypernym [city](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81847)

#### Tests

Yes A is one of the Bs
No B is one of the As

Condition: A is a proper noun (or named entity), B is a common noun.

#### Comments

Sometimes modelled as hyponomy/hypernymy relations.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="instance_hypernym"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | Instance Hypernym |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | @i |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_instance |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | typ |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | hypes |

* * *

### [Antonym](https://globalwordnet.github.io/gwadoc/#antonym) (antonym)[back to top](https://globalwordnet.github.io/gwadoc/#)

"An opposite and inherently incompatible word"

| symbol | ⇔ |
| --- |
| applicability | * synset–synset * sense–sense |
| reverse | [antonym](https://globalwordnet.github.io/gwadoc/#antonym) |
| example | [smart](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/2474) has antonym [stupid](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/2478) |

#### Definition

Two words are antonyms if their meanings are opposite in some way such as:

> 1.   The two words show binary opposition: [superior](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/93443) vs [inferior](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90690) (simple)
> 2.   The two words are near the opposite ends of a spectrum: [hot](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/6824) vs [cold](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/63356) (gradable)
> 3.   The two words express change or movement in opposite directions: [buy](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/32788) vs [sell](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/41243) (converse)

Antonymy can link any two members of any part-of-speech — verbs (e.g. dress vs. undress), adverbs (e.g. naturally vs. unnaturally), adjectives (e.g. superior vs. inferior) and nouns (e.g. catalyst vs. anti-catalyst), but should only ever link concepts with the same part-of-speech.

Antonymy is not transitive: If A is an antonym of B and B an antonym of C, then A is not necessarily and antonym of A. Consider _domestic_ ⇔ _national_ ⇔ _international_: it does not follow that _domestic_ ⇔ _international_, or _sister_ ⇔ _brother_ ⇔ _sister_ does not imply _sister_ ⇔ _sister_.

#### Examples

*   [man](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/91182) has antonym [woman](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/94168)
*   [superior](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/93443) has antonym [inferior](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90690)
*   [buy](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/32788) has antonym [sell](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/32953)
*   [northen](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/8760) has antonym [southern](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/8772)
*   [homosexual](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90552) has antonym [heterosexual](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/6566)
*   [sister](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/93015) has antonym [brother](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/88710)

#### Tests

Antonym-relation between nouns (EWN 16)

yes a _A and B are both a kind of C but A is the opposite of B_
.b _the converse of (a)_
Conditions:
*   A and B are singular or plural nouns
*   C is a hyperonym of both A and C and within a reasonable, competitive denotational range.

Antonym-relation between verb (EWN 17)

yes a _If something/someone/it As then something/someone/it does not B_
.b _If something/someone/it Bs then something/someone/it does not A)_
Conditions:
*   A is a synset variant in the third person singular form
*   B is a synset variant in the third person singular form
*   A and B are members of co-hyponym synsets
*   there is a hyperonym of A which is opposite to a hyperonym of B
*   the situation referred to by A has an addressee and the addressee is the protagonist of the situation referred to by B

Antonym-relation between verbs and adjectives (or adverbs) EWN 20

yes a _If something/someone/it As then something/someone/it is not B_
.b _If something/someone/it is B then something/someone/it does not A_
Conditions:
*   A is a verb in the third person singular form
*   B is an adjective
*   A and B are (XPOS) co-hyponyms

#### Comments

It is primarily a relation between senses, but sense level antonymy implies a looser synset level relation, which we automatically add to make it avaiable for wordnets that do not yet have sense level links.

plWordnet distinguishes between 'conversion' which is the same relationship form different points of vie, like _wife_ and _husband_ and normal antonymy, (plwordnet p27), proper and complementary antonymy.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="antonym"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="antonym"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | antonym |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | ! |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | antonym |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | antonim |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | antonym |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i69547](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69547)⟫ |

* * *

### [Equal Synonym](https://globalwordnet.github.io/gwadoc/#eq_synonym) (eq_synonym)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A and B are equivalent concepts but their nature requires that they remain separate (e.g. Exemplifies)"

| symbol | ≡ |
| --- |
| applicability | * synset–synset |
| reverse | [eq_synonym](https://globalwordnet.github.io/gwadoc/#eq_synonym) |
| example | [people](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/79059) has equal synonym [folks](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/79084) |

#### Definition

A relation between two concepts where A and B are equivalent concepts but their nature requires that they remain separate.

Equality is a self-reciprocal link (the two directions of this relation share the same meaning) — Concept-A is equal to Concept-B, and Concept-B is equal to Concept-A.

It denotes a special kind full synonimity that allows separation of synonym lemmas in two different synsets. It can occur with any type of part-of-speech.

At the moment, we're currently making use of this in order to isolate chengyu (成语), a traditional four-character Chinese idiom.

#### Examples

*   一模一样 (70100056-a) EQUALS identical (02068946-a) identical
*   (02068946-a) EQUALS 一模一样 (70100056-a)
*   [people](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/79059) has equal-synonym [folks](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/79084)
*   [cop](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/88724) has equal-synonym [policeman](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/92109)
*   [fiddle](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/30406) has equal-synonym [violin](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/60869)
*   [begin](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23466) has equal-synonym [start](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23481)

#### Tests

Equal Synonym-relation between nouns (EWN 1)

yes a _if it is (a/an) A then it is also (a/an) B_
.b _if it is (a/an) B then it is also (a/an) A_
Conditions:
*   A and B are singular or plural nouns

Equal Synonym-relation between verbs (EWN 2)

yes a _If something/someone/it As then something/someone/it Bs_
.b _If something/someone/it Bs then something/someone/it As_
Conditions:
*   A is a verb in the third person singular form
*   B is a verb in the third person singular form
*   there are no specifying PPs that apply to the A-phrase or the B-phrase

#### Comments

In principle all semantically equivalent words should belong to the same synsets (where they can be differentiated by labels on the appropriate usage).

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="eq_synonym"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | eq_synonym |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | synonim |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i69607](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69607)⟫ |

* * *

### [Similar](https://globalwordnet.github.io/gwadoc/#similar) (similar)[back to top](https://globalwordnet.github.io/gwadoc/#)

"(of words) expressing closely related meanings"

| applicability | * synset–synset * sense–sense |
| --- |
| reverse | [similar](https://globalwordnet.github.io/gwadoc/#similar) |
| example | * [tool](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/36325) has near_synonym [instrument](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/33440) |

#### Definition

A relation between two concepts where concept A and concept B are closely related in meaning but are not in the same synset. Similarity is a self-reciprocal link (the two directions of this relation share the same meaning) — Concept-A is similar to Concept-B, and Concept-B is similar to Concept-A.

This link was originally used to relate adjectives, but we have unconstrained this use, and we're making use of this link to relate all parts-of-speech.

Similarity can be understood as weak synonymy, opposed to the full synonymy that all lemmas in a concept must share. As adjectives are not structured hierarchically (hyponymy/hypernymy) like verbs or nouns, the similarity link helps showing relations between them.

#### Examples

*   [instrument](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/33440) has near_synonym [tools](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/36325)

#### Tests

Similar-relation between nouns (EWN 3)

yes a _if it is a/an A then it is also a kind of B but you usually do not call Cn Bs_
.b _if it is a/an B then it is also a kind of A but you usually do not call Cm As_
Conditions:
*   Cn are hyponyms of A, Cm are hypnyms of B.

#### Comments

This relation coerces PWN Similar to relation for adjectives, Verb Group relation for verbs and EWN NEAR_SYNONYM for nouns and verbs. In plWN Similarity relation for adjectives to nouns is a unilateral sense relation which is why it is not given in the mappings below.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="similar"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="similar"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | Similar to and Verb Group |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | *! |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | near_synonym |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | podobny |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | sim |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i13187](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/13187)⟫ |

* * *

### [Meronym](https://globalwordnet.github.io/gwadoc/#meronym) (meronym)[back to top](https://globalwordnet.github.io/gwadoc/#)

"B makes up a part of A"

| applicability | * synset–synset |
| --- |
| reverse | [holonym](https://globalwordnet.github.io/gwadoc/#holonym) |
| example | [hand](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/66153) has part-meronym [finger](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/66162) |

#### Definition

A relation between two concepts where concept A makes up a part of concept B.

#### Examples

*   [hat](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54674) has part-meronym [crown](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/52548)
*   [people](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/79059) has member-meronym [person](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/35562)
*   [water](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/115069) has substance-meronym [hydrogen](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/113946)

#### Tests

Meronymy-relation between nouns (EWN test 21)

yes a _A/an A makes up a part of A/an B_
.._A/an B has A/an As_
.._A is a meronym of "B" if As are parts of B(s)_
no b the converse of the (a) relations.

Conditions: - A and B are concrete nouns and are interpreted generically.

#### Comments

This is an unspecified relation that covers all the relations below. This can be computed automatically, it shouldn't be a special relation.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="meronym"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | meronym |
| --- |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_meronym |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | meronimia |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | mero |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i69575](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69575)⟫ |

* * *

### [Holonym](https://globalwordnet.github.io/gwadoc/#holonym) (holonym)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A makes up a part of B"

| applicability | * synset–synset |
| --- |
| reverse | [meronym](https://globalwordnet.github.io/gwadoc/#meronym) |
| example | [finger](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/66162) has part-holonym [hand](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/66153) |

#### Definition

A relation between two concepts where concept A makes up a part of concept B.

#### Examples

*   [eye](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/64868) has part-holonym [face](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/87210)
*   [planet](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85986) has member-holonym [solar system](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/86215)
*   [kibibyte](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/108305) has part-holonym [mebibyte](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/108309)

#### Tests

Holonymy-relation between nouns

yes a _A is a holonym of B if Bs are parts of As_
.._A is a holonym of B if Bs are members of As_
no b the converse of any of the (a) sentences.

#### Comments

This is an unspecified relation that covers all the relations below. This can be computed automatically, it shouldn't be a special relation.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="holonym"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | # |
| --- |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_holonym |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | holonimia |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | holo |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i69567](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69567)⟫ |

* * *

### [Location Meronym](https://globalwordnet.github.io/gwadoc/#mero_location) (mero_location)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A is a place located in B"

| applicability | * synset–synset |
| --- |
| reverse | [holo_location](https://globalwordnet.github.io/gwadoc/#holo_location) |
| example | [city](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81847) has mero_location [centre](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83693) |

#### Definition

A relation between two concepts where concept A is a place located in concept B.

#### Examples

*   [desert](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81751) has part-meronym [oasis](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81753)

#### Tests

Location meronymy -relation between nouns (EWN test 26)

yes a _a/an/the A is a place located in a/an/the B_
no b the converse of (a).

Conditions:

*   A is a concrete noun
*   B is a concrete noun

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="mero_location"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_mero_location |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | miejsce |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | mero |

* * *

### [Location Holonym](https://globalwordnet.github.io/gwadoc/#holo_location) (holo_location)[back to top](https://globalwordnet.github.io/gwadoc/#)

"B is a place located in A"

| applicability | * synset–synset |
| --- |
| reverse | [mero_location](https://globalwordnet.github.io/gwadoc/#mero_location) |
| example | [centre](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83693) has holo_location [city](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81847) |

#### Definition

A relation between two concepts where concept B is a place located in concept A.

#### Examples

*   [space](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81724) has part-holonym [aerospace](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81733)

#### Tests

Location meronymy -relation between nouns (EWN test 26)

yes a _a/an/the B is a place located in a/an/the A_
no b the converse of (a).

Conditions:

*   B is a concrete noun
*   A is a concrete noun

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="holo_location"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_holo_location |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | miejsce |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | holo |

* * *

### [Member Meronym](https://globalwordnet.github.io/gwadoc/#mero_member) (mero_member)[back to top](https://globalwordnet.github.io/gwadoc/#)

"Concept A is a member of Concept B"

| applicability | * synset–synset |
| --- |
| reverse | [holo_member](https://globalwordnet.github.io/gwadoc/#holo_member) |
| example | [player](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/92069) has member-meronym [team](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/80236) |

#### Definition

A relation between two concepts where concept A is a member/ element of concept B. Meronym and Holonym Membership is a paired relation that denotes group formation and membership. Is different from hyponym as it does not relates a sub-kind of a concept. It links groups to members — Many instances of Concept-A form Concept-B; and Concept-B is composed of many members of Concept-A.

#### Examples

*   [fleet](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/80725) has member-meronym [ship](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/58798)

#### Tests

Member meronymy -relation between nouns (EWN test 22)

yes a _a/an A is a member/element of (a/an/the) B_
no b the converse of (a).

Conditions:

*   A is a single object-denoting noun
*   B is a multiform noun (either a group-noun, a collective-noun or as a lexicalized plural denoting multiple objects)
*   preferably humans, animals, plants or vehicles or closed sets such as the number system, or the alphabet.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="mero_member"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | member meronym |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | %m |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_mero_member |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | element kolekcji |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | mmem |

* * *

### [Member Holonym](https://globalwordnet.github.io/gwadoc/#holo_member) (holo_member)[back to top](https://globalwordnet.github.io/gwadoc/#)

"Concept B is a member of Concept A"

| applicability | * synset–synset |
| --- |
| reverse | [mero_member](https://globalwordnet.github.io/gwadoc/#mero_member) |
| example | [team](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/80236) has member-holonym [player](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/92069) |

#### Definition

A relation between two concepts where concept B is a member/ element of concept A. Meronym and Holonym Membership is a paired relation that denotes group formation and membership. Is different from hyponym as it does not relates a sub-kind of a concept. It links groups to members — Concept-B is composed of many members of Concept-A; and many instances of Concept-A form Concept-B.

#### Examples

*   [ship](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/58798) has member-holonym [fleet](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/80725)

#### Tests

Member holonymy -relation between nouns (EWN test 22)

yes a _a/an B is a member/element of (a/an/the) A_
no b the converse of (a).

Conditions:

*   B is a multiform noun (either a group-noun, a collective-noun or as a lexicalized plural denoting multiple objects)
*   A is a single object-denoting noun
*   preferably humans, animals, plants or vehicles or closed sets such as the number system, or the alphabet.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="holo_member"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | member holonym |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | #m |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_holo_member |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | element kolekcji |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | hmem |

* * *

### [Part Meronym](https://globalwordnet.github.io/gwadoc/#mero_part) (mero_part)[back to top](https://globalwordnet.github.io/gwadoc/#)

"concept A is a component of concept B"

| applicability | * synset–synset |
| --- |
| reverse | [holo_part](https://globalwordnet.github.io/gwadoc/#holo_part) |
| example | [car](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51496) has part-meronym [wheel](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/61096) |

#### Definition

A relation between two concepts where concept A is a component of concept B. Meronym and Holonym Part is a paired relation that denotes proper parts (separable, in principle), which preserve a belonging relation even if the physical link is broken — Concept-A can be separated into Concept-B”; and Concept-B is a part of some Concept-A.

This relation is also frequently used to denote geographical inclusiveness relations.

#### Examples

*   [glove](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54319) has part-meronym [finger](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/53712)

#### Tests

Meronymy-relation between nouns (EWN test 24)

yes a _a/an A is a component of a/an B_
.b _a/an B is a whole/system/complex/network/arrangement/construction of parts/components among which a/an A_

Condition:

*   A and B are concrete nouns denoting objects, there must be several As

#### Comments

This relation is also frequently used by PWN to denote geographical inclusiveness relations.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="mero_part"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | part meronym |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | %p |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_mero_part |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | część |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | mprt |

* * *

### [Part Holonym](https://globalwordnet.github.io/gwadoc/#holo_part) (holo_part)[back to top](https://globalwordnet.github.io/gwadoc/#)

"Concept B is the whole where Concept A is a part"

| applicability | * synset–synset |
| --- |
| reverse | [mero_part](https://globalwordnet.github.io/gwadoc/#mero_part) |
| example | [wheel](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/61096) has part-holonym [car](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51496) |

#### Definition

A relation between two concepts where concept B is the whole of the different component of concept A. Meronym and Holonym Part is a paired relation that denotes proper parts (separable, in principle), which preserve a belonging relation even if the physical link is broken — Concept-A can be separated into Concept-B”; and Concept-B is a part of some Concept-A.

This relation is also frequently used to denote geographical inclusiveness relations.

#### Examples

*   [thumb](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/60231) has part-holonym [glove](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54319)

#### Tests

Holonymy-relation between nouns (EWN test 24)

yes a _a/an B is a whole/system/complex/network/arrangement/construction of parts/components among which a/an A_
.b _a/an A is a component of a/an B_

Condition:

*   B and A are concrete nouns denoting objects, B typically includes a larger entity

#### Comments

The has_holo-part relation typically relates components to their wholes, namely: something which is either topologically or temporally included in a larger entity and which as well bears some kind of autonomy (non-arbitrary boundaries) and a definite function with respect to the whole.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="holo_part"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | part holonym |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | #p |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_holo_part |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | część |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | hprt |

* * *

### [Portion Meronym](https://globalwordnet.github.io/gwadoc/#mero_portion) (mero_portion)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A is an amount/piece/portion of B"

| applicability | * synset–synset |
| --- |
| reverse | [holo_portion](https://globalwordnet.github.io/gwadoc/#holo_portion) |
| example | [drop](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/109995) has mero-portion [liquid](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/115633) |

#### Definition

A relation between two concepts where concept A is an amount/piece/portion of concept B.

#### Examples

*   [Nigeria](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83853) has part-meronym [Abuja](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83854)

#### Tests

Portion meronymy -relation between nouns (EWN test 26)

yes a _(a/an) A is an (amount/piece/portion) of B_
no b the converse of (a).

Conditions:

*   A and B are substance denoting nouns

#### Comments

usually portions (as concepts) do not receive a separate lexical item but are realized by sense extension (for instance, there is no lexical item equivalent to “portion of cake”);

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="mero_portion"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | portion meronym |
| --- |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_mero_portion |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | porcja |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | mprt |

* * *

### [Portion Holonym](https://globalwordnet.github.io/gwadoc/#holo_portion) (holo_portion)[back to top](https://globalwordnet.github.io/gwadoc/#)

"B is an amount/piece/portion of A"

| applicability | * synset–synset |
| --- |
| reverse | [mero_portion](https://globalwordnet.github.io/gwadoc/#mero_portion) |
| example | [liquid](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/115633) has holo-portion [drop](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/109995) |

#### Definition

A relation between two concepts where concept B is an amount/piece/portion of concept A

#### Examples

*   [Africa](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/84937) has part-holonym [Eastern Hemisphere](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81982)

#### Tests

Portion holonymy -relation between nouns (EWN test 26)

yes a _(a/an) B is the whole amount/piece of A_
no b the converse of (a).

Conditions:

*   B and A are substance denoting nouns

#### Comments

The whole always pre-exist the portion.Sometimes portions are sufficiently common in a particular language to become lexicalized. These lexical items will be linked to their wholes by means of a has_holo_portion

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="holo_portion"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_holo_portion |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | porcja |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | hprt |

* * *

### [Substance Meronym](https://globalwordnet.github.io/gwadoc/#mero_substance) (mero_substance)[back to top](https://globalwordnet.github.io/gwadoc/#)

"Concept A is made of concept B."

| applicability | * synset–synset |
| --- |
| reverse | [holo_substance](https://globalwordnet.github.io/gwadoc/#holo_substance) |
| example | [stick](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/59571) has substance-meronym [wood](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/116549) |

#### Definition

A relation between two concepts where concept A is made of concept B. Meronym and Holonym Substance is a paired relation that denotes a higher bound between part and whole. Separating/removing the substance part, will change the whole — Concept-A is made of Concept-B; and Concept-B is a substance of Concept-A”.

#### Examples

*   [paper](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/115832) has substance-meronym [cellulose](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/114776)
*   [wood](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/116549) has substance-meronym [lignin](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/115606)

#### Tests

Substance meronymy -relation between nouns (EWN test 25)

yes a _a/an A is made of B_
no b the converse of (a).

Conditions:

*   A is a concrete object
*   B is a concrete substance

#### Comments

There are two basic ways of viewing entities in the world, namely either as an individuated thing or as the stuff from which they are made of. This way, for instance a book can be alternatively named “a book” or “paper”. The relation between things and the stuff which compose them is called MADE_OF.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="mero_substance"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | substance meronym |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | %s |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_mero_madeof |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | materiał |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | msub |

* * *

### [Substance Holonym](https://globalwordnet.github.io/gwadoc/#holo_substance) (holo_substance)[back to top](https://globalwordnet.github.io/gwadoc/#)

"Concept-B is a substance of Concept-A"

| applicability | * synset–synset |
| --- |
| reverse | [mero_substance](https://globalwordnet.github.io/gwadoc/#mero_substance) |
| example | [wood](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/116549) has substance-holonym [stick](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/59571) |

#### Definition

A relation between two concepts where concept B is made of concept A. Meronym and Holonym Substance is a paired relation that denotes a higher bound between part and whole. Separating/removing the substance part, will change the whole — Concept-A is made of Concept-B; and Concept-B is a substance of Concept-A”.

#### Examples

*   [wood](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/116549) has substance-holonym [beam](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/50617)

#### Tests

Substance holonymy -relation between nouns (EWN test 25)

yes a _a/an B is substance of A_
no b the converse of (a).

Conditions:

*   B is a concrete substance
*   A is a concrete object

#### Comments

Complex holonyms can also contain substances but in that case the MADE_OF relation is used.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="holo_substance"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | substance holonym |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | #s |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_holo_madeof |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | materiał |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | hsub |

* * *

### [Other](https://globalwordnet.github.io/gwadoc/#other) (other)[back to top](https://globalwordnet.github.io/gwadoc/#)

"Any relation not otherwise specified"

| applicability | * synset–synset * sense–synset * sense–sense |
| --- |
| example | [doctor](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/89560) other [hospital](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/79536) |

#### Definition

This is used for semantic relation types not currently supported by the OMW DTD. The exact relation type can be given with dc:type:

<SynsetRelation relType="other" dc:type="emotion" target="example-en-1234-n"/>

#### Examples

*   [curator](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/89345) other [museum](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/56456)
*   [priest](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/92229) other [church](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/40809)
*   [mailman](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/91159) other [post office](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/79962)
*   [mayor](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/91277) other [town hall](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/60420)
*   [judge](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90808) other [court](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/52438)
*   [ambassador](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/88178) other [embassy](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/53393)
*   [gardener](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90153) other [garden](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54178)

#### Tests

yes a _A has some strong relation to B_
no b the converse of any of the (a) sentences.

#### Comments

This has no reverse, as we cannot be sure what the relation is gong to be. However, in most cases we would expect there to be a reverse relation.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="other"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="other"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | fuzzynym |
| --- |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | fuzzynym |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | fuzzynimia |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i11342](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/11342)⟫ |

* * *

### [See also](https://globalwordnet.github.io/gwadoc/#also) (also)[back to top](https://globalwordnet.github.io/gwadoc/#)

"a word having a loose semantic relation to another word"

| symbol | ☞ |
| --- |
| applicability | * synset–synset * sense–sense |
| reverse | [also](https://globalwordnet.github.io/gwadoc/#also) |
| example | [time](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/35582) see also [moment](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/117356) |

#### Definition

‘See Also’ is a self-reciprocal link (the two directions of this relation share the same meaning) — Concept-A relates to Concept-B, and Concept-B relates to Concept-A.

It denotes a relation of related meaning with another concept (going beyond synonymy and similarity).

This link was only used to relate adjectives and verbs in Princeton wordnet, but we have unconstrained this use, and we're making use of this link to relate all parts-of-speech.

#### Examples

*   [farmer](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/89889) see also [farmland](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/82016)
*   [learn](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/24750) see also [school](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/58518)
*   [picture](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/56911) see also [sculpture](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/40330)
*   [plant](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/35564) see also [flower](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/98673)
*   [walk](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/36884) see also [park](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/82259)

#### Tests

yes a _A has some loose relation to B_
no b the converse of any of the (a) sentences.

#### Comments

This could perhaps be merged with other

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="also"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="also"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | Also see |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | ^ |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | see also |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | dystrybutywność |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | also |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i18418](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/18418)⟫ |

* * *

### [State Of](https://globalwordnet.github.io/gwadoc/#state_of) (state_of)[back to top](https://globalwordnet.github.io/gwadoc/#)

"B is qualified by A"

| applicability | * synset–synset |
| --- |
| reverse | [be_in_state](https://globalwordnet.github.io/gwadoc/#be_in_state) |
| example | [poor](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/11083) state_of [have-not](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/92132) |

#### Definition

A relation between two concepts where concept B is qualified by concept A.

#### Examples

*   [poor](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/11083) state_of [have-not](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/92132)
*   [rich](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/11080) state_of [rich person](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/92571)

#### Tests

State Of - relation between noun (EWN 44)

yes a _B is the state that applies to A_
Conditions:
*   B is an adjective/adverb.
*   A is a noun.

#### Comments

In plWordNet it is a relation between lexical units. FCB: isn't this the same as attribute (but split into two directions)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="state_of"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | attribute |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | = |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | state_of |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | stan|cecha |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i35578](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/35578)⟫ |

* * *

### [Be In State](https://globalwordnet.github.io/gwadoc/#be_in_state) (be_in_state)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A is qualified by B"

| applicability | * synset–synset |
| --- |
| reverse | [state_of](https://globalwordnet.github.io/gwadoc/#state_of) |
| example | [have-not](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/92132) be in state [poor](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/11083) |

#### Definition

A relation between two concepts where concept A is qualified by concept B.

A is qualified by B.

#### Examples

*   [have-not](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/92132) be in state [poor](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/11083)
*   [rich person](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/92571) be in state [rich](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/11080)

#### Tests

Be In State - relation between adjective/adverb (EWN 44)

yes a _a/an/the A is the one/that to whom/which the state B applies_
Conditions:
*   A is a noun.
*   B is an adjective/adverb.

#### Comments

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="be_in_state"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | be_in_state |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | nosiciel_stanu|cechy |

* * *

### [Causes](https://globalwordnet.github.io/gwadoc/#causes) (causes)[back to top](https://globalwordnet.github.io/gwadoc/#)

"Concept A is an entity that produces an effect or is responsible for events or results of Concept B."

| applicability | * synset–synset |
| --- |
| reverse | [is_caused_by](https://globalwordnet.github.io/gwadoc/#is_caused_by) |
| example | [kill](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/28306) causes [die](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23529) |

#### Definition

A relation between two concepts where concept B comes into existence as a result of concept A. Entailment is a relation that links two verbs, and it is currently unilateral — Verb-A causes Verb-B, without a reciprocal or tracing link. Causation presupposes/requires that some Verb-B will, inevitably, take place during or after Verb-A (e.g. if Verb-A occurs, then Verb-B will also occur).

While not exclusive to these types of verbs, many verbs that have both a transitive and an intransitive form will frequently be submitted to this relation.

#### Examples

*   [kill](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/28306) causes [die](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23529)

#### Tests

Causes - relation (EWN 36)

yes a _(To/A/an) A causes (to/a/an) B to take place_
.._(To/A/an) A has (to/a/an) B as a consequence_
.._(To/A/an) A leads to (to/a/an) B_
no b _the converse of (a)_
Conditions:
*   A is a verb in the infinitive form or A is a noun in the singular
*   B is a verb in the infinitive form or B is a noun in the singular

Causes - relation between verbs and adjectives (or adverbs) (EWN 37)

yes a _A causes to be B_
.._A has being B as a consequence_
.._A leads to be(ing) B_
no b _the converse of (a)_

Conditions: - A is a verb in the infinitive form - B is and adjective

#### Comments

EUWN's definition of CAUSES is broader than that of PWN. It seems possible to just absorb PWN's links.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="causes"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | cause |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | > |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | causes |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | cause |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | caus |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i35561](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/35561)⟫ |

* * *

### [Is Caused By](https://globalwordnet.github.io/gwadoc/#is_caused_by) (is_caused_by)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A comes about because of B"

| applicability | * synset–synset |
| --- |
| reverse | [causes](https://globalwordnet.github.io/gwadoc/#causes) |
| example | [die](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23529) is caused by [kill](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/28306) |

#### Definition

A relation between two concepts where concept A comes into existence as a result of concept B.

#### Examples

*   [die](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23529) is caused by [kill](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/28306)

#### Tests

Is Caused By - relation (EWN 36)

yes a _(To/A/an) B takes place because of A_
.._(To/A/an) B is the consequence A_
.._(To/A/an) B is the result of A_
no b _the converse of (a)_
Conditions:
*   A is a verb in the infinitive form or A is a noun in the singular
*   B is a verb in the infinitive form or B is a noun in the singular

Is Caused By - relation between verbs and adjectives (or adverbs) (EWN 37)

yes a _B is caused by A_
.._B is the consequence of A_
.._B is the result of A_
no b _the converse of (a)_

Conditions:

*   A is a verb in the infinitive form
*   B is and adjective

#### Comments

The 'is caused by' relation was missing from PWN before.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="is_caused_by"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | is_caused_by |
| --- |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | caus |

* * *

### [Subevent](https://globalwordnet.github.io/gwadoc/#subevent) (subevent)[back to top](https://globalwordnet.github.io/gwadoc/#)

"B takes place during or as part of A, and whenever B takes place, A takes place"

| applicability | * synset–synset |
| --- |
| reverse | [is_subevent_of](https://globalwordnet.github.io/gwadoc/#is_subevent_of) |
| example | [sleep](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21840) has subevent [snore](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21852) |

#### Definition

A relation between two concepts where concept B takes place during or as part of concept A, and whenever concept B takes place, concept A takes place.

#### Examples

*   [sleep](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21840) has subevent [snore](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21852)

#### Tests

Subevent - relation between verbs/nouns (a) (EWN 41)

yes a _B takes place during or as a part of A, and whenever B takes place, A takes place_
no b _the converse of (a)_

Conditions:

*   A is a verb in the gerundive form
*   B is a verb in the gerundive form

Subevent - relation between verbs/nouns (b) (EWN 42)

yes a _A consists of B and other events or processes_
no b _the converse of (a)_

Conditions:

*   B is a verb in the gerundive form
*   A is a verb in the gerundive form buying consists of paying and other events or processes

#### Comments

The SUBEVENT relation is very useful for many closely related verbs and appeals more directly to human-intuitions (parallel to part-whole relation of concrete entities).

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="subevent"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | \* |
| --- |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | has_subevent |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | holonimia sytuacji towarzyszącej |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | enta |

* * *

### [Is Subevent Of](https://globalwordnet.github.io/gwadoc/#is_subevent_of) (is_subevent_of)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A takes place during or as part of B, and whenever A takes place, B takes place"

| applicability | * synset–synset |
| --- |
| reverse | [subevent](https://globalwordnet.github.io/gwadoc/#subevent) |
| example | [snore](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21852) is subevent of [sleep](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21840) |

#### Definition

A relation between two concepts where concept A takes place during or as part of concept B, and whenever concept A takes place, concept B takes place.

#### Examples

*   [snore](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21852) is subevent of [sleep](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21840)
*   [pay](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/i32996) is subevent of [buy](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/33154)

#### Tests

Is Subevent Of - relation between verbs/nouns (a) (EWN 41)

yes a _A takes place during or as a part of B, and whenever A takes place, B takes place_
no b _the converse of (a)_

Conditions:

*   A is a verb in the gerundive form
*   B is a verb in the gerundive form

Is Subevent Of - relation between verbs/nouns (b) (EWN 42)

yes a _A consists of B and other events or processes_
no b _the converse of (a)_

Conditions:

*   B is a verb in the gerundive form
*   A is a verb in the gerundive form buying consists of paying and other events or processes

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="is_subevent_of"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | * |
| --- |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | is_subevent_of |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | meronimia sytuacji towarzyszącej |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | enta |

* * *

### [Manner Of](https://globalwordnet.github.io/gwadoc/#manner_of) (manner_of)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A qualifies the manner in which an action or event expressed by B takes place"

| applicability | * synset–synset |
| --- |
| reverse | [in_manner](https://globalwordnet.github.io/gwadoc/#in_manner) |
| example | [noisily](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/19718) manner of [slurp](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27462) |

#### Definition

A relation between two concepts where concept A qualifies the manner in which an action or event expressed by concept B takes place.

#### Examples

*   [noisily](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/19718) manner of [slurp](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27462)

#### Tests

Manner Of - relation between verbs/adverb (EWN 43)

yes a _a manner of B which qualifies A_

Conditions:

*   A and B are verbs
*   B is the hyperonym of A
*   C is an adjective/adverb

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="manner_of"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | manner_of |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | sposób |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | enta |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i62791](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/62791)⟫ |

* * *

### [In Manner](https://globalwordnet.github.io/gwadoc/#in_manner) (in_manner)[back to top](https://globalwordnet.github.io/gwadoc/#)

"B qualifies the manner in which an action or event expressed by A takes place"

| applicability | * synset–synset |
| --- |
| reverse | [manner_of](https://globalwordnet.github.io/gwadoc/#manner_of) |
| example | [slurp](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27462) in manner [noisily](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/19718) |

#### Definition

A relation between two concepts where concept B qualifies the manner in which an action or event expressed by concept A takes place.

#### Examples

*   [slurp](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27462) in manner [noisily](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/19718)

#### Tests

In Manner - relation between verbs/adverb (EWN 43)

yes a _to A is to B in a C manner/way._

Conditions:

*   A and B are verbs
*   B is the hyperonym of A
*   C is an adjective/adverb

#### Comments

In EuroWordNet, we decided not to differentiate between troponymy and hyponymy but to use the IN_MANNER and MANNER_OF relation in addition to normal hyponymy to make the manner component explicit (if it is significant in the meaning of the verb):

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="in_manner"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | in_manner |
| --- |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | enta |

* * *

### [Attribute](https://globalwordnet.github.io/gwadoc/#attribute) (attribute)[back to top](https://globalwordnet.github.io/gwadoc/#)

"an abstraction belonging to or characteristic of an entity"

| applicability | * synset–synset |
| --- |
| reverse | [attribute](https://globalwordnet.github.io/gwadoc/#attribute) |
| example | [fertile](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/5483) has attributes [fecundity](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/110773) |

#### Definition

A relation between nominal and adjectival concepts where the concept A is an attribute of concept B. ‘Attributes’ is a self-reciprocal link (the two directions of this relation share the same meaning) — Concept-A attributes to Concept-B, and Concept-B attributes to Concept-A.

It denotes a relation between a noun and its adjectival attributes, and vice-versa — for this reason it should only link adjectives to nouns and vice-versa.

#### Examples

*   [fertile](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/5483) has attributes [fecundity](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/110773)
*   [fecundity](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/110773) has attributes [fertile](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/5483)

#### Tests

Attribute-relation between nouns and adjectives (EWN 14)

yes a _A is an attribute of B_
.._B is an attribute of A_
no b the converse of any of the (a) sentences.

Conditions: - A is a noun in the singular - B is an adjective - there is at least one specifying adverb, NP or PP that applies to the A- phrase or the B-phrase - preferably there is a no morphological link between the noun and the adjective

#### Comments

In plWN Value_of_the_attribute is a unilateral relation from adjectives to nouns.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="attribute"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | attribute |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | = |
| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | XPOS_Hyponymy |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | Attribute |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | attr |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i35577](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/35577)⟫ |

* * *

### [Restricts](https://globalwordnet.github.io/gwadoc/#restricts) (restricts)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A relation between an adjectival A (quantifier/determiner) and a nominal (pronominal) B"

| applicability | * synset–synset |
| --- |
| reverse | [restricted_by](https://globalwordnet.github.io/gwadoc/#restricted_by) |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

#### Definition

A relation between an adjectival concept A (quantifier/determiner) and a nominal (pronominal) concept B.

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

This would work for features like 'medial' or 'proximal' in pronouns, or 'every' in everybody, or 'male' for male personal pronouns, but not masculine agreeement in gendered languages. This relation will include some things that are now marked as domain usage. (to be corrected soon'ish)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="restricts"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i22888](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/22888)⟫ |
| --- |

* * *

### [Restricted By](https://globalwordnet.github.io/gwadoc/#restricted_by) (restricted_by)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A relation between nominal (pronominal) B and an adjectival A (quantifier/determiner)"

| applicability | * synset–synset |
| --- |
| reverse | [restricts](https://globalwordnet.github.io/gwadoc/#restricts) |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

#### Definition

A relation between nominal (pronominal) concept B and an adjectival concept A (quantifier/determiner).

#### Examples

*   this-a (77000061-a) QUANTIFIES [qant] this-n (77000061-n)
*   this-n (77000061-n) QUANTIFIER: [hasq] this-a (77000061-a)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="restricted_by"
		  target="wn-synset-B"/>
</Synset>

* * *

### [Classifies](https://globalwordnet.github.io/gwadoc/#classifies) (classifies)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept A used when counting concept B"

| applicability | * synset–synset |
| --- |
| reverse | [classified_by](https://globalwordnet.github.io/gwadoc/#classified_by) |
| example | [head](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/42274) classifies [cattle](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48233) |

#### Definition

A concept A used when counting concept B.

English does not really use this relationship, but it is common in many languages, such as Chinese, Japanese or Indonesian. A classifier is a word (or often a bound morpheme) which accompanies a noun in certain grammatical contexts, typically individuation, and generally reflects some kind of conceptual classification of nouns, based principally on features of their referents. Thus a language might have one classifier for nouns representing persons, another for nouns representing flat objects, another for nouns denoting periods of time, and so on. The assignment of classifier to noun may also be to some degree unpredictable, with certain nouns taking certain classifiers by historically established convention.

Note that the in a classifier language a classifier does not introduce a new referent, so we treat it as as non-referential.

#### Examples

*   [head](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/42274) classifies [cattle](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48233)
*   rasher classifies bacon
*   ekor classifiers kucil (Indonesian)
*   匹 classifies 猫 (Japanese)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

This relation was introduced in [DaCosta:Bond:2016]

[DaCosta:Bond:2016]Luis Morgado Da Costa, Francis Bond (2016) [Wow! What a Useful Extension! Introducing Non-Referential Concepts to Wordnet](https://www.aclweb.org/anthology/L16-1685.pdf) In _Proceedings of the Tenth International Conference on Language Resources and Evaluation_

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="classifies"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i25399](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/25399)⟫ |
| --- |

* * *

### [Classified By](https://globalwordnet.github.io/gwadoc/#classified_by) (classified_by)[back to top](https://globalwordnet.github.io/gwadoc/#)

"Concept B is modified by classifier A when it is counted."

| applicability | * synset–synset |
| --- |
| reverse | [classifies](https://globalwordnet.github.io/gwadoc/#classifies) |
| example | [cattle](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48233) is classified_by [head](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/42274) |

#### Definition

Concept B is modified by classifier A when it is counted.

#### Examples

*   'cattle <https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48233>`_ is classified_by [head](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/42274)
*   bacon is classified_by rasher
*   kucil is classified_by ekor (Indonesian)
*   猫 is classified_by 匹 (Japanese)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

This relation was introduced in [DaCosta:Bond:2016]

[DaCosta:Bond:2016]Luis Morgado Da Costa, Francis Bond (2016) [Wow! What a Useful Extension! Introducing Non-Referential Concepts to Wordnet](https://www.aclweb.org/anthology/L16-1685.pdf) In _Proceedings of the Tenth International Conference on Language Resources and Evaluation_

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="classified_by"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i25002](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/25002)⟫ |
| --- |

* * *

### [Entails](https://globalwordnet.github.io/gwadoc/#entails) (entails)[back to top](https://globalwordnet.github.io/gwadoc/#)

"impose, involve, or imply as a necessary accompaniment or result"

| applicability | * synset–synset |
| --- |
| reverse | [is_entailed_by](https://globalwordnet.github.io/gwadoc/#is_entailed_by) |
| example | [snore](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21852) entails [sleep](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21840) |

#### Definition

Entailment is a relation that links two verbs, and it is currently unilateral — Verb-A entails Verb-B, without a reciprocal or tracing link. This relation presupposes/requires a semantic restriction in which Verb-B has to take place before or during Verb-A.

#### Examples

*   [snore](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21852) entails [sleep](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21840)

#### Tests

yes a _A cannot be done unless B is or has been done_
no b the converse of any of the (a) sentences.

#### Comments

A verb A entails B if A cannot be done unless B is, or has been, done.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="entails"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | entailment |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | holonimia podsytuacji |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | enta |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i34846](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/34846)⟫ |

* * *

### [Is Entailed By](https://globalwordnet.github.io/gwadoc/#is_entailed_by) (is_entailed_by)[back to top](https://globalwordnet.github.io/gwadoc/#)

"Opposite of entails"

| applicability | * synset–synset |
| --- |
| reverse | [entails](https://globalwordnet.github.io/gwadoc/#entails) |
| example | [sleep](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21840) is entailed by [snore](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21852) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

#### Examples

*   [sleep](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21840) is entailed by [snore](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/21852)

#### Tests

yes a _B is the result/happens because of the occurrence of A_
no b the converse of any of the (a) sentences.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="is_entailed_by"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | meronimia podsytuacji |
| --- |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | enta |

* * *

### [Domain](https://globalwordnet.github.io/gwadoc/#domain) (domain)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is a Topic, Region or Usage pointer of a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [has_domain](https://globalwordnet.github.io/gwadoc/#has_domain) |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

#### Definition

Domain is an underspecified relation between two concepts where Concept B is a Topic (scientific category), Region or Usage pointer of Concept A.

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

This is an underspecified relation that covers Domain Topic, Domain Region, and Is Exemplified By. As such, it is not specified as a relation directly by wordnets, but a wordnet application may employ it as a general relation covering all its subtypes.

In EuroWordNet, Domain is moved to a separate ontology.(EuroWordNet General Document pp 8–10)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="domain"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | domain |
| --- |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | domn |

* * *

### [In Domain](https://globalwordnet.github.io/gwadoc/#has_domain) (has_domain)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is a term of a given Topic, Region or Usage concept."

| applicability | * synset–synset |
| --- |
| reverse | [domain](https://globalwordnet.github.io/gwadoc/#domain) |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

#### Definition

In Domain is an underspecified relation between two concepts where Concept A is a Topic (scientific category, Region or Usage term of Concept B.

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

This is an underspecified relation that covers Has Domain Topic, Has Domain Region, and Exemplifies. As such, it is not specified as a relation directly by wordnets, but a wordnet application may employ it as a general relation covering all its subtypes.

In EuroWordNet, In Domain is moved to a separate ontology.(EuroWordNet General Document pp 8–10)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="has_domain"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | domain term |
| --- |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | domt |

* * *

### [Domain Topic](https://globalwordnet.github.io/gwadoc/#domain_topic) (domain_topic)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the scientific category pointer of a given concept."

| applicability | * synset–synset * sense–synset * sense–sense |
| --- |
| reverse | [has_domain_topic](https://globalwordnet.github.io/gwadoc/#has_domain_topic) |
| example | [computer science](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/68812) is a domain topic of [CPU](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51710) |

#### Definition

Domain Topic is a relation between two concepts where Concept B is a scientific category (e.g. computing, sport, biology, etc.) of concept A.

#### Examples

*   [football](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/37873) is a domain topic of [place-kick](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27159)
*   [plant](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/35564) is a domain topic of [evergreen](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/5001)
*   [ocean](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85897) is a domain topic of [water](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85104)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="domain_topic"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="domain_topic"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | Domain of synset - TOPIC |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | ;c |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | dmnc |

* * *

### [Has Domain Topic](https://globalwordnet.github.io/gwadoc/#has_domain_topic) (has_domain_topic)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is a term in the scientific category of a given concept."

| applicability | * synset–synset * sense–sense |
| --- |
| reverse | [domain_topic](https://globalwordnet.github.io/gwadoc/#domain_topic) |
| example | [CPU](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51710) has domain topic of [computer science](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/68812) |

#### Definition

Has Domain Topic is a relation between two concepts where Concept A is a scientific category (e.g. computing, sport, biology, etc.) of concept B.

#### Examples

*   [place-kick](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27159) has domain topic of [football](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/37873)
*   [evergreen](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/5001) has domain topic of [plant](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/35564)
*   [water](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85104) has domain topic of [ocean](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85897)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="has_domain_topic"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="has_domain_topic"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | Member of this domain - TOPIC |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | -c |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | dmtc |

* * *

### [Domain Region](https://globalwordnet.github.io/gwadoc/#domain_region) (domain_region)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is a geographical / cultural domain pointer of a given concept."

| applicability | * synset–synset * sense–synset * sense–sense |
| --- |
| reverse | [has_domain_region](https://globalwordnet.github.io/gwadoc/#has_domain_region) |
| example | [United States](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/84182) is a domain region of [billion](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/12132) |

#### Definition

Domain Region is a relation between two concepts where Concept B is a geographical / cultural domain of concept A.

#### Examples

*   [Japan](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83607) is a domain region of [sushi](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/78639)
*   [England](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83374) is a domain region of [War of the Roses](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/42242)
*   [Pacific](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85934) is a domain region of [Philippine Sea](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/42156)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

We also agreed to change the name for these (to include both geographical and cultural regions)! But I'm not sure to what...

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="domain_region"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="domain_region"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | Domain of synset - REGION |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | ;r |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | dmnr |

* * *

### [Has Domain Region](https://globalwordnet.github.io/gwadoc/#has_domain_region) (has_domain_region)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the term in the geographical / cultural domain of a given concept."

| applicability | * synset–synset * sense–sense |
| --- |
| reverse | [domain_region](https://globalwordnet.github.io/gwadoc/#domain_region) |
| example | [billion](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/12132) has domain region of [United States](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/84182) |

#### Definition

Has Domain Region is a relation between two concepts where Concept A is a term of the geographical / cultural domain of concept B.

#### Examples

*   [sushi](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/78639) has domain region of [Japan](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83607)
*   [War of the Roses](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/42242) has domain region of [England](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83374)
*   [Philippine Sea](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/42156) has domain region of [Pacific](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85934)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

We have discussed changing the name for these (as they include both geographical and cultural regions). But we have not yet come up with a good name.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="has_domain_region"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="has_domain_region"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | Member of this domain - REGION |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | -r |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | dmtr |

* * *

### [Exemplifies](https://globalwordnet.github.io/gwadoc/#exemplifies) (exemplifies)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the example of a given concept."

| applicability | * synset–synset * sense–synset * sense–sense |
| --- |
| reverse | [is_exemplified_by](https://globalwordnet.github.io/gwadoc/#is_exemplified_by) |
| example | [Band Aid](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/50429) exemplifies [trademark](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/72497) |

#### Definition

Exemplifies is a relation between two concepts where Concept A is the example of Concept B.

#### Examples

*   [wings](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/36358) exemplifies [plural form](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69585)
*   [Band Aid](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/50429) exemplifies [trademark](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/72497)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

The name was changed from "Member of this domain - USAGE" as we found it too different from the standard meaning of domain.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="exemplifies"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="exemplifies"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | Member of this domain - USAGE |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | -u |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | dmtu |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i108797](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/108797)⟫ |

* * *

### [Is Exemplified By](https://globalwordnet.github.io/gwadoc/#is_exemplified_by) (is_exemplified_by)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the type of a given concept."

| applicability | * synset–synset * sense–sense |
| --- |
| reverse | [exemplifies](https://globalwordnet.github.io/gwadoc/#exemplifies) |
| example | [trademark](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/72497) is exemplified by [Band Aid](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/50429) |

#### Definition

Is Exemplified By is a relation between two concepts where Concept B is a type of Concept A, such as idiom, honorific or classifier.

#### Examples

*   [trademark](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/72497) is exemplified by [Band Aid](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/50429)
*   [plural form](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69585) is exemplified by [wings](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/36358)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

We agreed to change the name for these with Christiane! We propose 'Exemplified_By'.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="is_exemplified_by"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="is_exemplified_by"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [Princeton WordNet Relation Name](https://wordnet.princeton.edu/documentation/wngloss7wn "Name used by the Princeton Wordnet") | Domain of synset - USAGE |
| --- |
| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | ;u |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | dmnu |

* * *

### [Role](https://globalwordnet.github.io/gwadoc/#role) (role)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is involved in the action or event expressed by a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [involved](https://globalwordnet.github.io/gwadoc/#involved) |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

#### Definition

Role is an underspecified relation between two concepts where concept A is typically involved in the action or event expressed by concept B.

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

#### Tests

Role / Involved as general relation (EWN test 29)

yes(a/an) A is the one/that who/which is typically involved in Bing
Conditions A is a noun
.B is a verb in the infinitive form
Example:A hammer is that which is typically involved in hammering
Effect:{hammer}(A) ROLE {to hammer}(B)
.{to hammer}(B) INVOLVED {hammer}(A)

#### Comments

This is an underspecified relation that covers Agent, Patient, Result, Instrument, Location, Direction, Target Direction, and Source Direction. As such, it is not specified as a relation directly by wordnets, but a wordnet application may employ it as a general relation covering all its subtypes.

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="role"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | role |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | rola |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i64041](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/64041)⟫ |

* * *

### [Involved](https://globalwordnet.github.io/gwadoc/#involved) (involved)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the action or event a given concept typically involved in."

| applicability | * synset–synset |
| --- |
| reverse | [role](https://globalwordnet.github.io/gwadoc/#role) |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

#### Definition

Involved is an underspecified relation between two concepts where concept B is the action or event concept A typically involved in.

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

#### Tests

Role / Involved as general relation (EWN test 29)

yes(a/an) A is the one/that who/which is typically involved in Bing
Conditions A is a noun
.B is a verb in the infinitive form
Example:A hammer is that which is typically involved in hammering
Effect:{hammer}(A) ROLE {to hammer}(B)
.{to hammer}(B) INVOLVED {hammer}(A)

#### Comments

This is an underspecified relation that covers Involved Agent, Involved Patient, Involved Result, Involved Instrument, Involved Location, Involved Direction, Involved Target Direction, and Involved Source Direction. As such, it is not specified as a relation directly by wordnets, but a wordnet application may employ it as a general relation covering all its subtypes.

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="involved"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | involved |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | unspecified subtype, time and causation inclusion |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i8315](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/8315)⟫ |

* * *

### [Agent](https://globalwordnet.github.io/gwadoc/#agent) (agent)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is typically the one/that who/which does the action denoted by a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [involved_agent](https://globalwordnet.github.io/gwadoc/#involved_agent) |
| example | [teacher](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/93557) is the agent of [to teach](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/25800) |

#### Definition

Agent is a relation between two concepts where Concept A is the semantic role of the animate entity that instigates or causes the happening of Concept B, typically intentionally.

#### Examples

*   [teacher](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/93557) is the agent of [to teach](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/25800)

#### Tests

Agent Involvement (EWN test 28)

yes a(A/an) A is the one/that who/which does the B, typically intentionally
Conditions:.*   A is a noun
..*   B is a verb in the gerundive form
Example:a A teacher is the one who does the teaching intentionally
Effect:.{teacher}(A) AGENT {to teach}(B)
..{to teach}(B) INVOLVED AGENT {teacher}(A)

#### Comments

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="agent"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | role_agent |
| --- |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i69754](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69754)⟫ |

* * *

### [Involved Agent](https://globalwordnet.github.io/gwadoc/#involved_agent) (involved_agent)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the action done by an agent expressed by a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [agent](https://globalwordnet.github.io/gwadoc/#agent) |
| example | [to teach](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/25800) involved agent [teacher](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/93557) |

#### Definition

Involved Agent is a relation between two concepts where concept B is typically the action done by the agent expressed by concept A.

#### Examples

*   [to teach](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/25800) involved agent [teacher](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/93557)

#### Tests

Agent Involvement (EWN test 28)

yes a(A/an) A is the one/that who/which does the B, typically intentionally
Conditions:.*   A is a noun
..*   B is a verb in the gerundive form
Example:a A teacher is the one who does the teaching intentionally
Effect:.{teacher}(A) AGENT {to teach}(B)
..{to teach}(B) INVOLVED AGENT {teacher}(A)

#### Comments

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="involved_agent"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | involved_agent |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | agent inclusion |

* * *

### [Patient](https://globalwordnet.github.io/gwadoc/#patient) (patient)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the one/that who/which undergoes a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [involved_patient](https://globalwordnet.github.io/gwadoc/#involved_patient) |
| example | [learner](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90958) is the patient of [to learn](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/24750) |

#### Definition

Patient is a relation between two concepts where Concept A is the semantic role of an entity that is not the agent but is directly involved in or affected by the happening denoted by Concept B.

#### Examples

*   [learner](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90958) is the patient of [to learn](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/24750)

#### Tests

Patient Involvement (EWN test 29)

yes a(A/an) A is the one/that who/which undergoes the B
Conditions:.*   A is a noun
..*   B is a verb in the gerundive form
Example:a A learner is the one who undergoes the learning
Effect:.{learner}(A) PATIENT {to learn}(B)
..{to learn}(B) INVOLVED PATIENT {learner}(A)

#### Comments

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="patient"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | role_patient |
| --- |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i69753](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69753)⟫ |

* * *

### [Involved Patient](https://globalwordnet.github.io/gwadoc/#involved_patient) (involved_patient)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the action that the patient expressed by a given concept undergoing."

| applicability | * synset–synset |
| --- |
| reverse | [patient](https://globalwordnet.github.io/gwadoc/#patient) |
| example | [to learn](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/24750) involved patient [learner](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90958) |

#### Definition

Involved Patient is a relation between two concepts where Concept B is typically an action or event that the patient expressed by Concept A undergoing.

#### Examples

*   [to learn](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/24750) involved patient [learner](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90958)

#### Tests

Patient Involvement (EWN test 29)

yes a(A/an) A is the one/that who/which undergoes the B
Conditions:.*   A is a noun
..*   B is a verb in the gerundive form
Example:a A learner is the one who undergoes the learning
Effect:.{learner}(A) PATIENT {to learn}(B)
..{to learn}(B) INVOLVED PATIENT {learner}(A)

#### Comments

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="involved_patient"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | involved_patient |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | patient inclusion |

* * *

### [Result](https://globalwordnet.github.io/gwadoc/#result) (result)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which comes into existence as a result of a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [involved_result](https://globalwordnet.github.io/gwadoc/#involved_result) |
| example | [crystal](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85286) is the result of [to crystalize](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23949) |

#### Definition

Result is a relation between two concepts where Concept A exists as a result only by virtue of the activity denoted by Concept B.

#### Examples

*   [crystal](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85286) is the result of [to crystalize](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23949)
*   [ice](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/115475) is the result of [to freeze](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23605)

#### Tests

Result Involvement (EWN test 30)

yes a(A/an) A comes into existence as a result of B
yes b(A/an) A is the result of B
yes c(A/an) A is created by B
Conditions:.*   A is a noun
..*   B is a verb in the gerundive form and a hyponym of “make”, “produce”, “enerate”.
Example:a a crystal comes into existence as a result of crystalizing
.b a crystal is the result of crystalizing
.c a crystal is created by crystalizing
Effect:.{crystal}(A) RESULT {to crystalize}(B)
..{to crystalize}(B) INVOLVED RESULT {crystal}(A)

#### Comments

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="result"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | role_result |
| --- |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i69759](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69759)⟫ |

* * *

### [Involved Result](https://globalwordnet.github.io/gwadoc/#involved_result) (involved_result)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the action or event with a result of a given concept comes into existence."

| applicability | * synset–synset |
| --- |
| reverse | [result](https://globalwordnet.github.io/gwadoc/#result) |
| example | [to crystalize](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23949) involved result of [crystal](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85286) |

#### Definition

Involved Result is a relation between two concepts where concept B comes into existence as a result of concept A.

#### Examples

*   [to crystalize](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23949) involved result of [crystal](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85286)
*   [to freeze](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/23605) involved result of [ice](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/115475)

#### Tests

Result Involvement (EWN test 30)

yes a(A/an) A comes into existence as a result of B
yes b(A/an) A is the result of B
yes c(A/an) A is created by B
Conditions:.*   A is a noun
..*   B is a verb in the gerundive form and a hyponym of “make”, “produce”, “enerate”.
Example:a a crystal comes into existence as a result of crystalizing
.b a crystal is the result of crystalizing
.c a crystal is created by crystalizing
Effect:.{crystal}(A) RESULT {to crystalize}(B)
..{to crystalize}(B) INVOLVED RESULT {crystal}(A)

#### Comments

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="involved_result"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | involved_result |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | result inclusion |

* * *

### [Instrument](https://globalwordnet.github.io/gwadoc/#instrument) (instrument)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the instrument necessary for the action or event expressed by a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [involved_instrument](https://globalwordnet.github.io/gwadoc/#involved_instrument) |
| example | [hammer](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54582) is the instrument of [to hammer](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/28810) |

#### Definition

Instrument is a relation between two concepts where Concept A is the semantic role of the entity (usually inanimate) that the agent uses to perform an action or start a process expressed by Concept B.

#### Examples

*   [hammer](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54582) is the instrument of [to hammer](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/28810)
*   [sail](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/58403) is the instrument of [to sail](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/31452)
*   [pen](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/28810) is the instrument of [to write](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/30198)
*   [ink](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/115490) is the instrument of [to write](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/30198)
*   [paper](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69377) is the instrument of [to write](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/30198)

#### Tests

Instrument Involvement (EWN test 31)

yes a(A/an) A is either i) the instrument that or ii) what is used to B (with)
Conditions:.*   A is a noun
..*   B is a verb in the infinitive form
Example (1):.An hammer is the instrument that is used to hammer
Effect:.{hammer}(A) INSTRUMENT {to hammer}(B)
Effect:.{to hammer}(B) INVOLVED INSTRUMENT {hammer}(A)
Example (2):.A sailing boat is what is used to sail with
Effect:.{sail}(A) INSTRUMENT {to sail}(B)
Example (3):.Pen/Ink/Paper is what is used to write
Effect:.{pen}(A) INSTRUMENT {to write}(B)
..{ink}(A) INSTRUMENT {to write}(B)
..{paper}(A) INSTRUMENT {to write}(B)

#### Comments

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="instrument"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | role_instrument |
| --- |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i69756](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69756)⟫ |

* * *

### [Involved Instrument](https://globalwordnet.github.io/gwadoc/#involved_instrument) (involved_instrument)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is typically the action with the instrument expressed by a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [instrument](https://globalwordnet.github.io/gwadoc/#instrument) |
| example | [to hammer](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/28810) involved instrument [hammer](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54582) |

#### Definition

Involved Instrument is a relation between two concepts where concept B is typically the action or event with the usage of instrument expressed by concept A.

#### Examples

*   [to hammer](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/28810) involved instrument [hammer](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54582)
*   [to sail](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/31452) involved instrument [sail](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/58403)
*   [to write](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/30198) involved instrument [pen](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/28810)
*   [to write](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/30198) involved instrument [ink](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/115490)
*   [to write](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/30198) involved instrument [paper](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/69377)

#### Tests

Instrument Involvement (EWN test 31)

yes a(A/an) A is either i) the instrument that or ii) what is used to B (with)
Conditions:.*   A is a noun
..*   B is a verb in the infinitive form
Example (1):.An hammer is the instrument that is used to hammer
Effect:.{hammer}(A) INSTRUMENT {to hammer}(B)
Effect:.{to hammer}(B) INVOLVED INSTRUMENT {hammer}(A)
Example (2):.A sailing boat is what is used to sail with
Effect:.{sail}(A) INSTRUMENT {to sail}(B)
Example (3):.Pen/Ink/Paper is what is used to write
Effect:.{pen}(A) INSTRUMENT {to write}(B)
..{ink}(A) INSTRUMENT {to write}(B)
..{paper}(A) INSTRUMENT {to write}(B)

#### Comments

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="involved_instrument"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | involved_instrument |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | instrument inclusion |

* * *

### [Location](https://globalwordnet.github.io/gwadoc/#location) (location)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the place where the event expressed by a given concept happens."

| applicability | * synset–synset |
| --- |
| reverse | [involved_location](https://globalwordnet.github.io/gwadoc/#involved_location) |
| example | [school](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/58518) is the location of [to teach](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/25800) |

#### Definition

Location is a relation between two concepts where concept A is the location where the action or event expressed by concept B takes place.

#### Examples

*   [school](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/58518) is the location of [to teach](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/25800)
*   [water](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85104) is the location of [to swim](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/31242)

#### Tests

Location Involvement (EWN test 32)

yes a(A/an) A is the place where the B happens
Conditions:.*   A is a noun
..*   B is a verb in the gerundive form
Example:a A school is the place where the teaching happens
Effect:.{school}(A) LOCATION {to teach}(B)
..{to teach}(B) INVOLVED LOCATION {school}(A)

#### Comments

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="location"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | role_location |
| --- |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i35580](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/35580)⟫ |

* * *

### [Involved Location](https://globalwordnet.github.io/gwadoc/#involved_location) (involved_location)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the event happening in a place expressed by a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [location](https://globalwordnet.github.io/gwadoc/#location) |
| example | [to teach](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/25800) involved location [school](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/58518) |

#### Definition

Involved Location is a relation between two concepts where concept B is typically the action or event which takes place in the location expressed by concept A.

#### Examples

*   [to teach](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/25800) involved location [school](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/58518)
*   [to swim](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/31242) involved location [water](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85104)

#### Tests

Location Involvement (EWN test 32)

yes a(A/an) A is the place where the B happens
Conditions:.*   A is a noun
..*   B is a verb in the gerundive form
Example:a A school is the place where the teaching happens
Effect:.{school}(A) LOCATION {to teach}(B)
..{to teach}(B) INVOLVED LOCATION {school}(A)

#### Comments

In plWordNet it is a relation between lexical units.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="involved_location"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | involved_location |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | location inclusion |

* * *

### [Direction](https://globalwordnet.github.io/gwadoc/#direction) (direction)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the direction of the action or event expressed by a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [involved_direction](https://globalwordnet.github.io/gwadoc/#involved_direction) |
| example | [place](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/82372) is the direction of [to pass](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27684) |

#### Definition

Direction is a relation between two concepts where concept A is typically the direction or location of the action or event expressed by concept B.

#### Examples

*   [place](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/82372) is the direction of [to pass](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27684)

#### Tests

Direction Involvement (EWN test 33)

yes a It is possible to B from/to/over/across/through a place (A)
Conditions:.*   B is a verb in the infinitive form
Example:a It is possible to pass though a place
Effect:.{place}(A) DIRECTION {to pass}(B)
..{to pass}(B) INVOLVED DIRECTION {place}(A)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="direction"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | role_direction |
| --- |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i82556](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/82556)⟫ |

* * *

### [Involved Direction](https://globalwordnet.github.io/gwadoc/#involved_direction) (involved_direction)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the action with the direction expressed by a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [direction](https://globalwordnet.github.io/gwadoc/#direction) |
| example | [to pass](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27684) involved direction [place](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/82372) |

#### Definition

Involved Direction is a relation between two concepts where concept B is typically the action or event with the direction or location expressed by concept A.

#### Examples

*   [to pass](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27684) involved direction [place](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/82372)

#### Tests

Direction Involvement (EWN test 33)

yes a It is possible to B from/to/over/across/through a place (A)
Conditions:.*   B is a verb in the infinitive form
Example:a It is possible to pass though a place
Effect:.{place}(A) DIRECTION {to pass}(B)
..{to pass}(B) INVOLVED DIRECTION {place}(A)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="involved_direction"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | involved_direction |
| --- |

* * *

### [Target Direction](https://globalwordnet.github.io/gwadoc/#target_direction) (target_direction)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the place where the action or event expressed by a given concept leads to."

| applicability | * synset–synset |
| --- |
| reverse | [involved_target_direction](https://globalwordnet.github.io/gwadoc/#involved_target_direction) |
| example | [ground](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85674) is the target direction of [to collapse](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/113799), [to fall](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/31590) heavily |

#### Definition

Target Direction is a relation between two concepts where Concept A is the place designated as the end (as of a race or journey) of an action or event expressed by Concept B.

#### Examples

*   [ground](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85674) is the target direction of [to collapse](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/113799), to [fall](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/31590) heavily
*   [home](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/53274) is the target direction of [to go back](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/26394)

#### Tests

Target-Direction Involvement (EWN test 35)

yes a(a/an/the) A is the place to which Bing happens / one Bs
Conditions:.*   A is a noun
..*   B is a verb
Example:a The ground is the place to which one collapses/falls heavily
Effect:.{ground}(A) TARGET DIRECTION {to collapse, to fall heavily}(B)
..{to collapse, to fall heavily}(B) INVOLVED TARGET DIRECTION {ground}(A)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="target_direction"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | role_target_direction |
| --- |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i82007](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/82007)⟫ |

* * *

### [Involved Target Direction](https://globalwordnet.github.io/gwadoc/#involved_target_direction) (involved_target_direction)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the action or event leading to a place expressed by a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [target_direction](https://globalwordnet.github.io/gwadoc/#target_direction) |
| example | [to collapse](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/113799), [to fall](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/31590) heavily involved target direction [ground](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85674) |

#### Definition

Involved Target Direction is a relation between two concepts where concept B is the the action or event leading to a place expressed by concept A.

#### Examples

*   [to collapse](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/113799), [to fall](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/31590) heavily involved target direction [ground](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85674)
*   [to go back](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/26394) involved target direction [home](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/53274)

#### Tests

Target-Direction Involvement (EWN test 35)

yes a(a/an/the) A is the place to which Bing happens / one Bs
Conditions:.*   A is a noun
..*   B is a verb
Example:a The ground is the place to which one collapses/falls heavily
Effect:.{ground}(A) TARGET DIRECTION { o collapse, to fall heavily}(B)
..{to collapse, to fall heavily}(B) INVOLVED TARGET DIRECTION {ground}(A)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="involved_target_direction"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | involved_target_direction |
| --- |

* * *

### [Source Direction](https://globalwordnet.github.io/gwadoc/#source_direction) (source_direction)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the place from where the event expressed by a given concept begins."

| applicability | * synset–synset |
| --- |
| reverse | [involved_source_direction](https://globalwordnet.github.io/gwadoc/#involved_source_direction) |
| example | the [start](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/75187) is the source direction of [to race](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27023) |

#### Definition

Source Direction is a relation between two concepts where concept A is the place from where the action or event expressed by concept B begins/starts/happens.

#### Examples

*   the [start](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/75187) is the source direction of [to race](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27023)
*   [ship](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/58798) is the source direction of [to debark](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/31629)

#### Tests

Source-Direction Involvement (EWN test 34)

yes a(A/an/the) A is the place from where Bing begins/starts/happens / one Bs
Conditions:.*   A is a noun
..*   B is a verb
Example:a The start is the place from where the racing starts
Effect:.{the start}(A) SOURCE DIRECTION {to race}(B)
..{to race}(B) INVOLVED SOURCE DIRECTION {the start}(A)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="source_direction"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | role_source_direction |
| --- |
| [Open Multilingual Wordnet Concept](https://lr.soh.ntu.edu.sg/omw/omw "OMW, linked by Interlingual Index") | ⟪[i81759](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/81759)⟫ |

* * *

### [Involved Source Direction](https://globalwordnet.github.io/gwadoc/#involved_source_direction) (involved_source_direction)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the action beginning from a place of a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [source_direction](https://globalwordnet.github.io/gwadoc/#source_direction) |
| example | [to race](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27023) involved source direction the [start](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/75187) |

#### Definition

Involved Source Direction is a relation between two concepts where concept B is the action or event which begins/starts/happens from a place expressed by concept A.

#### Examples

*   [to race](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/27023) involved source direction the [start](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/75187)
*   [to debark](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/31629) involved source direction [ship](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/58798)

#### Tests

Source-Direction Involvement (EWN test 34)

yes a(A/an/the) A is the place from where Bing begins/starts/happens / one Bs
Conditions:.*   A is a noun
..*   B is a verb
Example:a The start is the place from where the racing starts
Effect:.{the start}(A) SOURCE DIRECTION {to race}(B)
..{to race}(B) INVOLVED SOURCE DIRECTION {the start}(A)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="involved_source_direction"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | involved_source_direction |
| --- |

* * *

### [Co Role](https://globalwordnet.github.io/gwadoc/#co_role) (co_role)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept undergoes an action in which a given concept is involved."

| applicability | * synset–synset |
| --- |
| reverse | [co_role](https://globalwordnet.github.io/gwadoc/#co_role) |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

#### Definition

Co Role is an underspecified relation between two concepts where Concept A undergoes an action in which Concept B is involved (bidirectional).

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

This is an underspecified relation that covers Co Agent Patient, Co Patient Agent, Co Agent Instrument, Co Instrument Agent, Co Agent Result, Co Result Agent, Co Patient Instrument, Co Instrument Patient, Co Result Instrument, and Co Instrument Result. As such, it is not specified as a relation directly by wordnets, but a wordnet application may employ it as a general relation covering all its subtypes.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="co_role"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | co_role |
| --- |

* * *

### [Co Agent Patient](https://globalwordnet.github.io/gwadoc/#co_agent_patient) (co_agent_patient)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the patient undergoing an action carried out by a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [co_patient_agent](https://globalwordnet.github.io/gwadoc/#co_patient_agent) |
| example | [victim](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/93927) is the co agent patient of [criminal](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/89309) |

#### Definition

Co Agent Patient is a relation between two concepts where Concept B is the patient undergoing an action carried out by Concept A.

#### Examples

*   [victim](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/93927) is the co agent patient of [criminal](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/89309)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="co_agent_patient"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | co_agent_patient |
| --- |

* * *

### [Co Patient Agent](https://globalwordnet.github.io/gwadoc/#co_patient_agent) (co_patient_agent)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which carries out an action a given concept undergoing."

| applicability | * synset–synset |
| --- |
| reverse | [co_agent_patient](https://globalwordnet.github.io/gwadoc/#co_agent_patient) |
| example | [criminal](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/89309) is the co patient agent of [victim](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/93927) |

#### Definition

Co Patient Agent is a relation between two concepts where Concept A carries out an action Concept B undergoing.

#### Examples

*   [criminal](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/89309) is the co patient agent of [victim](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/93927)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="co_patient_agent"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | co_patient_agent |
| --- |

* * *

### [Co Agent Instrument](https://globalwordnet.github.io/gwadoc/#co_agent_instrument) (co_agent_instrument)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the instrument used by a given concept in an action."

| applicability | * synset–synset |
| --- |
| reverse | [co_instrument_agent](https://globalwordnet.github.io/gwadoc/#co_instrument_agent) |
| example | [guitar](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54496) is the co agent instrument of [guitar player](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90355) |

#### Definition

Co Agent Instrument is a relation between two concepts where Concept B is the instrument used by Concept A in a certain action.

#### Examples

*   [guitar](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54496) is the co agent instrument of [guitar player](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90355)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="co_agent_instrument"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | co_agent_instrument |
| --- |

* * *

### [Co Instrument Agent](https://globalwordnet.github.io/gwadoc/#co_instrument_agent) (co_instrument_agent)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which carries out an action by using a given concept as an instrument."

| applicability | * synset–synset |
| --- |
| reverse | [co_agent_instrument](https://globalwordnet.github.io/gwadoc/#co_agent_instrument) |
| example | [guitar player](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90355) is the co instrument agent of [guitar](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54496) |

#### Definition

Co Instrument Agent is a relation between two concepts where Concept A carries out an action by using Concept B as an instrument.

#### Examples

*   [guitar player](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/90355) is the co instrument agent of [guitar](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54496)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="co_instrument_agent"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | co_instrument_agent |
| --- |

* * *

### [Co Agent Result](https://globalwordnet.github.io/gwadoc/#co_agent_result) (co_agent_result)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the result of an action taken by a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [co_result_agent](https://globalwordnet.github.io/gwadoc/#co_result_agent) |
| example | [pastry](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/76902) is the co agent result of [pastry cook](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/91893) |

#### Definition

Co Agent Result is a relation between two concepts where Concept B is the result of an action carried out by Concept A.

#### Examples

*   [pastry](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/76902) is the co agent result of [pastry cook](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/91893)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="co_agent_result"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | co_agent_result |
| --- |

* * *

### [Co Result Agent](https://globalwordnet.github.io/gwadoc/#co_result_agent) (co_result_agent)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which takes an action resulting in a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [co_agent_result](https://globalwordnet.github.io/gwadoc/#co_agent_result) |
| example | [pastry cook](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/91893) is the co result agent of [pastry](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/76902) |

#### Definition

Co Result Agent is a relation between two concepts where Concept A takes an action resulting in Concept B.

#### Examples

*   [pastry cook](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/91893) is the co result agent of [pastry](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/76902)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="co_result_agent"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | co_result_agent |
| --- |

* * *

### [Co Patient Instrument](https://globalwordnet.github.io/gwadoc/#co_patient_instrument) (co_patient_instrument)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is used as an instrument in an action a given concept undergoes."

| applicability | * synset–synset |
| --- |
| reverse | [co_instrument_patient](https://globalwordnet.github.io/gwadoc/#co_instrument_patient) |
| example | [bread knife](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51098) is the co patient instrument of [bread](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/77313) |

#### Definition

Co Patient Instrument is a relation between two concepts where Concept B is the instrument used in an action which Concept A undergoes.

#### Examples

*   [bread knife](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51098) is the co patient instrument of [bread](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/77313)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="co_patient_instrument"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | co_patient_instrument |
| --- |

* * *

### [Co Instrument Patient](https://globalwordnet.github.io/gwadoc/#co_instrument_patient) (co_instrument_patient)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which undergoes an action with the use of a given concept as an instrument."

| applicability | * synset–synset |
| --- |
| reverse | [co_patient_instrument](https://globalwordnet.github.io/gwadoc/#co_patient_instrument) |
| example | [bread](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/77313) is the co instrument patient of [bread knife](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51098) |

#### Definition

Co Instrument Patient is a relation between two concepts where Concept A undergoes an action for which the instrument expressed by Concept B is used.

#### Examples

*   [bread](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/77313) is the co instrument patient of [bread knife](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51098)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="co_instrument_patient"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | co_instrument_patient |
| --- |

* * *

### [Co Result Instrument](https://globalwordnet.github.io/gwadoc/#co_result_instrument) (co_result_instrument)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is used as an instrument in an action resulting in a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [co_instrument_result](https://globalwordnet.github.io/gwadoc/#co_instrument_result) |
| example | [photograpic camera](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51401) is the co result instrument of [photo](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/57211) |

#### Definition

Co Result Instrument is a relation between two concepts where Concept B is an instrument used in an action resulting in Concept A.

#### Examples

*   [photograpic camera](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51401) is the co result instrument of [photo](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/57211)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="co_result_instrument"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | co_result_instrument |
| --- |

* * *

### [Co Instrument Result](https://globalwordnet.github.io/gwadoc/#co_instrument_result) (co_instrument_result)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is the result of an action using an instrument of a given concept."

| applicability | * synset–synset |
| --- |
| reverse | [co_result_instrument](https://globalwordnet.github.io/gwadoc/#co_result_instrument) |
| example | [photo](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/57211) is the co instrument result of [photograpic camera](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51401) |

#### Definition

Co Instrument Result is a relation between two concepts where Concept A is the result of an action carried out by the instrument expressed by Concept B.

#### Examples

*   [photo](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/57211) is the co instrument result of [photograpic camera](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/51401)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="co_instrument_result"
		  target="wn-synset-B"/>
</Synset>

#### Project-specific Names

| [Euro WordNet Relation Name](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf "Name used by Euro WordNet") | co_instrument_result |
| --- |

* * *

### [Participle](https://globalwordnet.github.io/gwadoc/#participle) (participle)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is a participial adjective derived from a verb expressed by a given concept."

| applicability | * sense–sense |
| --- |
| example | [interesting](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/7324) is the participial of [interest](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/30833) |

#### Definition

Participle is a relation between two concepts where Concept A is a participial adjective which is drived from Concept B in the form of verb.

#### Examples

*   [interesting](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/7324) is the participial of [interest](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/30833)
*   [amazing](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/6996) is the participial of [amaze](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/25324)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

These are not linked in the NLTK interface so are not shown in OMW 1.0 (or as far as I can see, anywhere FCB)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="participle"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | part |
| --- |

* * *

### [Pertainym](https://globalwordnet.github.io/gwadoc/#pertainym) (pertainym)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is of or pertaining to a given concept."

| symbol | ⊞ |
| --- |
| applicability | * sense–sense |
| reverse | [pertainym](https://globalwordnet.github.io/gwadoc/#pertainym) |
| example | [slowly](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/19235) is the pertainym of [slow](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/5362) |

#### Definition

Pertainym is a relation between two concepts where Concept A is related or applicable to Concept B. Typically A will be an adjective and B a noun, or A an adverb and B an adjective. It is typically used for adjectives that are morphologically related to the noun they are related to, are not gradable and do not have antonyms. It is also used for nouns that are semantically related but not morphologically related, typically because came from different languages historically, so _lunar_ for _moon_ or _arborial_ for _tree_.

#### Examples

*   [lunar](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/15548) is the pertainym of [moon](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/85806)
*   [naval](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/15629) is the pertainym of [navy](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/80195)
*   [slowly](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/19235) is the pertainym of [slow](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/5362)
*   [English](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/17163) is the pertainym of [England](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/83374)
*   [subclinical](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/16413) is the pertainym of [clinical](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/16412)
*   [clinical](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/16412) is the pertainym of [clinic](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/79534)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

This may be specialized further. It includes zero derivations. Gnerally it is used for different syntactic categories that have the same root form and are semantically related. Wordnet does not say which is the baseform, the relationship is fully reversible.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="pertainym"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | pert |
| --- |

* * *

### [Derivation](https://globalwordnet.github.io/gwadoc/#derivation) (derivation)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is a derivationally related form of a given concept."

| symbol | ⊳ |
| --- |
| applicability | * sense–sense |
| reverse | [derivation](https://globalwordnet.github.io/gwadoc/#derivation) |
| example | [yearly](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/10786) is the derivation of [year](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/117116) |

#### Definition

Derivation is a relation between two concept where Concept A is the derivationally related form of Concept B.

#### Examples

*   [yearly](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/10786) is the derivation of [year](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/117116)
*   [want(n)](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/113167) is the derivation of [want(v)](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/30852)
*   [provision](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/40949) is the derivation of [provide](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/33372)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="derivation"
		  target="wn-sense-B"/>
 </Sense>

#### Project-specific Names

| [Princeton WordNet Pointer](https://wordnet.princeton.edu/documentation/wninput5wn "Pointer symbol in the PWN text database") | + |
| --- |
| [PlWordNet Relation Name](http://plwordnet.pwr.wroc.pl/wordnet/about "Polish name used by the Polish WordNet") | derywacyjność |
| [PERL WordNet-QueryData Module](https://metacpan.org/pod/WordNet::QueryData#QUERYING "Relation name used by QueryData") | deri |

* * *

### [Simple Aspect (imp to per)](https://globalwordnet.github.io/gwadoc/#simple_aspect_ip) (simple_aspect_ip)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is linked to another through a change from imperfective to perfective aspect"

| applicability | * sense–sense |
| --- |
| reverse | [simple_aspect_pi](https://globalwordnet.github.io/gwadoc/#simple_aspect_pi) |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="simple_aspect_ip"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Simple Aspect (per to imp)](https://globalwordnet.github.io/gwadoc/#simple_aspect_pi) (simple_aspect_pi)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is linked to another through a change from perfective to imperfective aspect"

| applicability | * sense–sense |
| --- |
| reverse | [simple_aspect_ip](https://globalwordnet.github.io/gwadoc/#simple_aspect_ip) |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="simple_aspect_pi"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Secondary Aspect (ip)](https://globalwordnet.github.io/gwadoc/#secondary_aspect_ip) (secondary_aspect_ip)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is linked to another through a change in aspect (ip)"

| applicability | * sense–sense |
| --- |
| reverse | [secondary_aspect_pi](https://globalwordnet.github.io/gwadoc/#secondary_aspect_pi) |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="secondary_aspect_ip"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Secondary Aspect (pi)](https://globalwordnet.github.io/gwadoc/#secondary_aspect_pi) (secondary_aspect_pi)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which is linked to another through a change in aspect (pi)"

| applicability | * sense–sense |
| --- |
| reverse | [secondary_aspect_ip](https://globalwordnet.github.io/gwadoc/#secondary_aspect_ip) |
| example | [Contribute an example](https://github.com/globalwordnet/gwadoc) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="secondary_aspect_pi"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Feminine](https://globalwordnet.github.io/gwadoc/#feminine) (feminine)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept used to refer to female members of a class"

| symbol | ♀ |
| --- |
| applicability | * synset–synset * sense–sense |
| reverse | [has_feminine](https://globalwordnet.github.io/gwadoc/#has_feminine) |
| example | [sow](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48204) is the feminine of [pig](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48199) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="feminine"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="feminine"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Has Feminine](https://globalwordnet.github.io/gwadoc/#has_feminine) (has_feminine)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which has a special concept for female members of its class"

| symbol | ♀ |
| --- |
| applicability | * synset–synset * sense–sense |
| reverse | [feminine](https://globalwordnet.github.io/gwadoc/#feminine) |
| example | [pig](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48199) has the feminine [sow](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48204) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="has_feminine"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="has_feminine"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Masculine](https://globalwordnet.github.io/gwadoc/#masculine) (masculine)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept used to refer to male members of a class"

| symbol | ♂ |
| --- |
| applicability | * synset–synset * sense–sense |
| reverse | [has_masculine](https://globalwordnet.github.io/gwadoc/#has_masculine) |
| example | [boar](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48203) is the masculine of [pig](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48199) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="masculine"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="masculine"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Has Masculine](https://globalwordnet.github.io/gwadoc/#has_masculine) (has_masculine)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which has a special concept for male members of its class"

| symbol | ♂ |
| --- |
| applicability | * synset–synset * sense–sense |
| reverse | [masculine](https://globalwordnet.github.io/gwadoc/#masculine) |
| example | [pig](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48199) has the masculine [boar](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48203) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="has_masculine"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="has_masculine"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Young](https://globalwordnet.github.io/gwadoc/#young) (young)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept used to refer to young members of a class"

| applicability | * synset–synset |
| --- |
| reverse | [has_young](https://globalwordnet.github.io/gwadoc/#has_young) |
| example | [piglet](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48200) is a young [pig](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48199) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="young"
		  target="wn-synset-B"/>
</Synset>

* * *

### [Has Young](https://globalwordnet.github.io/gwadoc/#has_young) (has_young)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which has a special concept for young members of its class"

| applicability | * synset–synset |
| --- |
| reverse | [young](https://globalwordnet.github.io/gwadoc/#young) |
| example | [pig](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48199) has young [piglet](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/48200) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="has_young"
		  target="wn-synset-B"/>
</Synset>

* * *

### [Diminutive](https://globalwordnet.github.io/gwadoc/#diminutive) (diminutive)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept used to refer to generally smaller members of a class"

| applicability | * sense–sense |
| --- |
| reverse | [has_diminutive](https://globalwordnet.github.io/gwadoc/#has_diminutive) |
| example | [kitchenette](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/55399) is a diminutive [kitchen](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/55397) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="diminutive"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Has Diminutive](https://globalwordnet.github.io/gwadoc/#has_diminutive) (has_diminutive)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which has a special concept for generally smaller members of its class"

| applicability | * sense–sense |
| --- |
| reverse | [diminutive](https://globalwordnet.github.io/gwadoc/#diminutive) |
| example | [kitchen](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/55397) has diminutive [kitchenette](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/55399) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="has_diminutive"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Augmentative](https://globalwordnet.github.io/gwadoc/#augmentative) (augmentative)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept used to refer to generally larger members of a class"

| applicability | * sense–sense |
| --- |
| reverse | [has_augmentative](https://globalwordnet.github.io/gwadoc/#has_augmentative) |
| example | [great house](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/7550) is a larger [house](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54960) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="augmentative"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Has Augmentative](https://globalwordnet.github.io/gwadoc/#has_augmentative) (has_augmentative)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept which has a special concept for generally larger members of its class"

| applicability | * sense–sense |
| --- |
| reverse | [augmentative](https://globalwordnet.github.io/gwadoc/#augmentative) |
| example | [house](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/54960) has larger [great house](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/7550) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="has_augmentative"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Gradable Antonym](https://globalwordnet.github.io/gwadoc/#anto_gradable) (anto_gradable)[back to top](https://globalwordnet.github.io/gwadoc/#)

"word pairs whose meanings are opposite and which lie on a continuous spectrum"

| applicability | * synset–synset * sense–sense |
| --- |
| reverse | [anto_gradable](https://globalwordnet.github.io/gwadoc/#anto_gradable) |
| example | [hot](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/6824) is a gradable antonym [cold](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/63356) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### Comments

Also known as just _converse_ or _relational antonym_.

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="anto_gradable"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="anto_gradable"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Simple Antonym](https://globalwordnet.github.io/gwadoc/#anto_simple) (anto_simple)[back to top](https://globalwordnet.github.io/gwadoc/#)

"word pairs whose meanings are opposite but whose meanings do not lie on a continuous spectrum"

| applicability | * synset–synset * sense–sense |
| --- |
| reverse | [anto_simple](https://globalwordnet.github.io/gwadoc/#anto_simple) |
| example | [alive](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/496) is a simple antonym [dead](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/527) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="anto_simple"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="anto_simple"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Converse Antonym](https://globalwordnet.github.io/gwadoc/#anto_converse) (anto_converse)[back to top](https://globalwordnet.github.io/gwadoc/#)

"word pairs that name or describe a single relationship from opposite perspectives"

| applicability | * synset–synset * sense–sense |
| --- |
| reverse | [anto_converse](https://globalwordnet.github.io/gwadoc/#anto_converse) |
| example | [parent](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/91858) is a converse antonym of [child](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/88965) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="anto_converse"
		  target="wn-synset-B"/>
</Synset>

<Sense id="wn-sense-A" synset="wn-synset-A">
   <SenseRelation relType="anto_converse"
		  target="wn-sense-B"/>
 </Sense>

* * *

### [Inter-register Synonym](https://globalwordnet.github.io/gwadoc/#ir_synonym) (ir_synonym)[back to top](https://globalwordnet.github.io/gwadoc/#)

"A concept that means the same except for the style or connotation"

| symbol | ≅ |
| --- |
| applicability | * synset–synset |
| reverse | [ir_synonym](https://globalwordnet.github.io/gwadoc/#ir_synonym) |
| example | [loot](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/106350) is an inter-register synonym of [money](https://lr.soh.ntu.edu.sg/omw/omw/concepts/ili/107057) |

[Contribute a definition](https://github.com/globalwordnet/gwadoc)

[Contribute more examples](https://github.com/globalwordnet/gwadoc)

[Contribute test](https://github.com/globalwordnet/gwadoc)

#### XML

In the [XML format for Wordnet LMF](https://github.com/globalwordnet/schemas) the relation should be shown like this:

<Synset id="wn-synset-A" ili="iXYZ" partOfSpeech="x">
  <SynsetRelation relType="ir_synonym"
		  target="wn-synset-B"/>
</Synset>

* * *

### References

*   Christiane Fellbaum (ed.) (1998) _WordNet: An Electronic Lexical Database_, MIT Press 
    *   [Princeton WordNet Documentation](https://wordnet.princeton.edu/documentation/)

*   Piek Vossen (ed.) (1999) 

[EuroWordNet General Document](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf)
*   Maciej Piasecki, Stanisław Szpakowicz, Bartosz Broda (2009) 

[A Wordnet from the Ground Up](https://globalwordnet.github.io/gwadoc/pdf/EWN_general.pdf)
*   [Open Multilingual WordNet](https://lr.soh.ntu.edu.sg/omw/omw)
*   [XML format for WordNet LMF](https://github.com/globalwordnet/schemas)